/*
 * JNpp - Java bindings for NPP, to be used with JCuda
 *
 * Copyright (c) 2010-2013 Marco Hutter - http://www.jcuda.org
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
package jcuda.jnpp;

import jcuda.*;
import jcuda.jnpp.types.*;

/**
 * Java bindings for the signal functions of NPP. Most of the documentation
 * is extracted from the NPPI header files.
 */
public class JNpps
{
    /**
     * Private constructor to prevent instantiation
     */
    private JNpps()
    {
    }

    static
    {
        JNpp.initialize();
    }

    //=== Auto-generated part ================================================

    /**
     * <pre>
     * 8-bit unsigned signal allocator.
     * @param nSize Number of unsigned chars in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp8u> nppsMalloc_8u(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_8uNative(nSize));
    }
    private static native TypedPointer<Npp8u> nppsMalloc_8uNative(
        int nSize);


    /**
     * <pre>
     * 8-bit signed signal allocator.
     * @param nSize Number of (signed) chars in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp8s> nppsMalloc_8s(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_8sNative(nSize));
    }
    private static native TypedPointer<Npp8s> nppsMalloc_8sNative(
        int nSize);


    /**
     * <pre>
     * 16-bit unsigned signal allocator.
     * @param nSize Number of unsigned shorts in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp16u> nppsMalloc_16u(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_16uNative(nSize));
    }
    private static native TypedPointer<Npp16u> nppsMalloc_16uNative(
        int nSize);


    /**
     * <pre>
     * 16-bit signal allocator.
     * @param nSize Number of shorts in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppsMalloc_16s(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_16sNative(nSize));
    }
    private static native TypedPointer<Npp16s> nppsMalloc_16sNative(
        int nSize);


    /**
     * <pre>
     * 16-bit complex-value signal allocator.
     * @param nSize Number of 16-bit complex numbers in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp16s> nppsMalloc_16sc(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_16scNative(nSize));
    }
    private static native TypedPointer<Npp16s> nppsMalloc_16scNative(
        int nSize);


    /**
     * <pre>
     * 32-bit unsigned signal allocator.
     * @param nSize Number of unsigned ints in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp32u> nppsMalloc_32u(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_32uNative(nSize));
    }
    private static native TypedPointer<Npp32u> nppsMalloc_32uNative(
        int nSize);


    /**
     * <pre>
     * 32-bit integer signal allocator.
     * @param nSize Number of ints in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp32s> nppsMalloc_32s(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_32sNative(nSize));
    }
    private static native TypedPointer<Npp32s> nppsMalloc_32sNative(
        int nSize);


    public static TypedPointer<Npp32s> nppsMalloc_32sc(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_32scNative(nSize));
    }
    private static native TypedPointer<Npp32s> nppsMalloc_32scNative(
        int nSize);


    /**
     * <pre>
     * 32-bit float signal allocator.
     * @param nSize Number of floats in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppsMalloc_32f(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_32fNative(nSize));
    }
    private static native TypedPointer<Npp32f> nppsMalloc_32fNative(
        int nSize);


    /**
     * <pre>
     * 32-bit complex float signal allocator.
     * @param nSize Number of complex float values in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp32f> nppsMalloc_32fc(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_32fcNative(nSize));
    }
    private static native TypedPointer<Npp32f> nppsMalloc_32fcNative(
        int nSize);


    /**
     * <pre>
     * 64-bit long integer signal allocator.
     * @param nSize Number of long ints in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp64s> nppsMalloc_64s(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_64sNative(nSize));
    }
    private static native TypedPointer<Npp64s> nppsMalloc_64sNative(
        int nSize);


    /**
     * <pre>
     * 64-bit complex long integer signal allocator.
     * @param nSize Number of complex long int values in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp64s> nppsMalloc_64sc(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_64scNative(nSize));
    }
    private static native TypedPointer<Npp64s> nppsMalloc_64scNative(
        int nSize);


    /**
     * <pre>
     * 64-bit float (double) signal allocator.
     * @param nSize Number of doubles in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp64f> nppsMalloc_64f(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_64fNative(nSize));
    }
    private static native TypedPointer<Npp64f> nppsMalloc_64fNative(
        int nSize);


    /**
     * <pre>
     * 64-bit complex complex signal allocator.
     * @param nSize Number of complex double valuess in the new signal.
     * @return
     *  A pointer to the new signal. 0 (NULL-pointer) indicates
     *         that an error occurred during allocation.
     * </pre>
     */
    public static TypedPointer<Npp64f> nppsMalloc_64fc(
        int nSize)
    {
        return JNpp.checkResult(nppsMalloc_64fcNative(nSize));
    }
    private static native TypedPointer<Npp64f> nppsMalloc_64fcNative(
        int nSize);


    /**
     * <pre>
     * Free method for any signal memory.
     * @param pValues A pointer to memory allocated using nppiMalloc_<modifier>.
     * </pre>
     */
    public static void nppsFree(
        Pointer pValues)
    {
        nppsFreeNative(pValues);
    }
    private static native void nppsFreeNative(
        Pointer pValues);


    /**
     * <pre>
     * 8-bit unsigned char, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_8u(
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_8uNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_8uNative(
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength);


    public static int nppsSet_8s(
        byte nValue,
        TypedPointer<Npp8s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_8sNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_8sNative(
        byte nValue,
        TypedPointer<Npp8s> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned integer, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_16u(
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_16uNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_16uNative(
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed integer, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_16s(
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_16sNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_16sNative(
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit integer complex, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_16sc(
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_16scNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_16scNative(
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_32u(
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_32uNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_32uNative(
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength);


    public static int nppsSet_32s(
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_32sNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_32sNative(
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit integer complex, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_32sc(
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_32scNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_32scNative(
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit float, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_32f(
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_32fNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_32fNative(
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit float complex, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_32fc(
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_32fcNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_32fcNative(
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit long long integer, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_64s(
        long nValue,
        TypedPointer<Npp64s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_64sNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_64sNative(
        long nValue,
        TypedPointer<Npp64s> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit long long integer complex, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_64sc(
        Npp64sc nValue,
        TypedPointer<Npp64s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_64scNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_64scNative(
        Npp64sc nValue,
        TypedPointer<Npp64s> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit double, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_64f(
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_64fNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_64fNative(
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit double complex, vector set method.
     * @param nValue Value used to initialize the vector pDst.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSet_64fc(
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSet_64fcNative(nValue, pDst, nLength));
    }
    private static native int nppsSet_64fcNative(
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char, vector zero method.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZero_8u(
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_8uNative(pDst, nLength));
    }
    private static native int nppsZero_8uNative(
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit integer, vector zero method.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZero_16s(
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_16sNative(pDst, nLength));
    }
    private static native int nppsZero_16sNative(
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit integer complex, vector zero method.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZero_16sc(
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_16scNative(pDst, nLength));
    }
    private static native int nppsZero_16scNative(
        TypedPointer<Npp16s> pDst,
        int nLength);


    public static int nppsZero_32s(
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_32sNative(pDst, nLength));
    }
    private static native int nppsZero_32sNative(
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit integer complex, vector zero method.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZero_32sc(
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_32scNative(pDst, nLength));
    }
    private static native int nppsZero_32scNative(
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit float, vector zero method.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZero_32f(
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_32fNative(pDst, nLength));
    }
    private static native int nppsZero_32fNative(
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit float complex, vector zero method.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZero_32fc(
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_32fcNative(pDst, nLength));
    }
    private static native int nppsZero_32fcNative(
        TypedPointer<Npp32f> pDst,
        int nLength);


    public static int nppsZero_64s(
        TypedPointer<Npp64s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_64sNative(pDst, nLength));
    }
    private static native int nppsZero_64sNative(
        TypedPointer<Npp64s> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit long long integer complex, vector zero method.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZero_64sc(
        TypedPointer<Npp64s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_64scNative(pDst, nLength));
    }
    private static native int nppsZero_64scNative(
        TypedPointer<Npp64s> pDst,
        int nLength);


    public static int nppsZero_64f(
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_64fNative(pDst, nLength));
    }
    private static native int nppsZero_64fNative(
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit double complex, vector zero method.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZero_64fc(
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsZero_64fcNative(pDst, nLength));
    }
    private static native int nppsZero_64fcNative(
        TypedPointer<Npp64f> pDst,
        int nLength);


    public static int nppsCopy_8u(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_8uNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_8uNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_16s(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_16sNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_16sNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed integer, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_32s(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_32sNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_32sNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit float, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit signed integer, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_64s(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_64sNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_64sNative(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit complex short, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_16sc(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_16scNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_16scNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex signed integer, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_32sc(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_32scNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_32scNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex float, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_32fcNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex signed integer, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_64sc(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_64scNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_64scNative(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex double, vector copy method.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCopy_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCopy_64fcNative(pSrc, pDst, nLength));
    }
    private static native int nppsCopy_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * @name Convert
     * Routines for converting the sample-data type of signals.
     *
     * @{
     *
     * </pre>
     */
    public static int nppsConvert_8s16s(
        TypedPointer<Npp8s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_8s16sNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_8s16sNative(
        TypedPointer<Npp8s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength);


    public static int nppsConvert_8s32f(
        TypedPointer<Npp8s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_8s32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_8s32fNative(
        TypedPointer<Npp8s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    public static int nppsConvert_8u32f(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_8u32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_8u32fNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    public static int nppsConvert_16s8s_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp8s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_16s8s_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_16s8s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp8s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_16s32s(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_16s32sNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_16s32sNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength);


    public static int nppsConvert_16s32f(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_16s32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_16s32fNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    public static int nppsConvert_16u32f(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_16u32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_16u32fNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    public static int nppsConvert_32s16s(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_32s16sNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_32s16sNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength);


    public static int nppsConvert_32s32f(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_32s32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_32s32fNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    public static int nppsConvert_32s64f(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_32s64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_32s64fNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    public static int nppsConvert_32f64f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_32f64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_32f64fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    public static int nppsConvert_64s64f(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_64s64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_64s64fNative(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    public static int nppsConvert_64f32f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsConvert_64f32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsConvert_64f32fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    public static int nppsConvert_16s32f_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_16s32f_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsConvert_16s32f_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsConvert_16s64f_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_16s64f_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsConvert_16s64f_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsConvert_32s16s_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_32s16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsConvert_32s16s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsConvert_32s32f_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_32s32f_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsConvert_32s32f_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsConvert_32s64f_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_32s64f_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsConvert_32s64f_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsConvert_32f8s_Sfs(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp8s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_32f8s_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_32f8s_SfsNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp8s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_32f8u_Sfs(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_32f8u_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_32f8u_SfsNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_32f16s_Sfs(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_32f16s_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_32f16s_SfsNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_32f16u_Sfs(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_32f16u_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_32f16u_SfsNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_32f32s_Sfs(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_32f32s_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_32f32s_SfsNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_64s32s_Sfs(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_64s32s_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_64s32s_SfsNative(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_64f16s_Sfs(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_64f16s_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_64f16s_SfsNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_64f32s_Sfs(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_64f32s_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_64f32s_SfsNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    public static int nppsConvert_64f64s_Sfs(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsConvert_64f64s_SfsNative(pSrc, pDst, nLength, eRoundMode, nScaleFactor));
    }
    private static native int nppsConvert_64f64s_SfsNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int eRoundMode,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_16s(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_16sNative(pSrc, pDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_16sNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        int nRelOp);


    /**
     * <pre>
     * 16-bit in place signed short signal threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_16s_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_16s_INative(pSrcDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_16s_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        int nRelOp);


    /**
     * <pre>
     * 16-bit signed short complex number signal threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_16sc(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_16scNative(pSrc, pDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_16scNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        int nRelOp);


    /**
     * <pre>
     * 16-bit in place signed short complex number signal threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_16sc_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_16sc_INative(pSrcDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_16sc_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        int nRelOp);


    /**
     * <pre>
     * 32-bit floating point signal threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_32fNative(pSrc, pDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        int nRelOp);


    /**
     * <pre>
     * 32-bit in place floating point signal threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_32f_INative(pSrcDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        int nRelOp);


    /**
     * <pre>
     * 32-bit floating point complex number signal threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_32fcNative(pSrc, pDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        int nRelOp);


    /**
     * <pre>
     * 32-bit in place floating point complex number signal threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_32fc_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_32fc_INative(pSrcDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_32fc_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        int nRelOp);


    /**
     * <pre>
     * 64-bit floating point signal threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_64fNative(pSrc, pDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        int nRelOp);


    public static int nppsThreshold_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_64f_INative(pSrcDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        int nRelOp);


    /**
     * <pre>
     * 64-bit floating point complex number signal threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_64fcNative(pSrc, pDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        int nRelOp);


    /**
     * <pre>
     * 64-bit in place floating point complex number signal threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nRelOp NppCmpOp type of thresholding operation (NPP_CMP_LESS or NPP_CMP_GREATER only).
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_64fc_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        int nRelOp)
    {
        return JNpp.checkResult(nppsThreshold_64fc_INative(pSrcDst, nLength, nLevel, nRelOp));
    }
    private static native int nppsThreshold_64fc_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        int nRelOp);


    /**
     * <pre>
     * 16-bit signed short signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_16s(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_16sNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_16sNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel);


    /**
     * <pre>
     * 16-bit in place signed short signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_16s_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_16s_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_16s_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel);


    /**
     * <pre>
     * 16-bit signed short complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_16sc(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_16scNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_16scNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel);


    /**
     * <pre>
     * 16-bit in place signed short complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_16sc_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_16sc_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_16sc_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel);


    /**
     * <pre>
     * 32-bit floating point signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_32fNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel);


    /**
     * <pre>
     * 32-bit in place floating point signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_32f_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel);


    /**
     * <pre>
     * 32-bit floating point complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_32fcNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel);


    public static int nppsThreshold_LT_32fc_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_32fc_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_32fc_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel);


    /**
     * <pre>
     * 64-bit floating point signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_64fNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel);


    /**
     * <pre>
     * 64-bit in place floating point signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_64f_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel);


    /**
     * <pre>
     * 64-bit floating point complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_64fcNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel);


    /**
     * <pre>
     * 64-bit in place floating point complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LT_64fc_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel)
    {
        return JNpp.checkResult(nppsThreshold_LT_64fc_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_LT_64fc_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel);


    /**
     * <pre>
     * 16-bit signed short signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_16s(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_16sNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_16sNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel);


    /**
     * <pre>
     * 16-bit in place signed short signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_16s_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_16s_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_16s_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel);


    /**
     * <pre>
     * 16-bit signed short complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_16sc(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_16scNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_16scNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel);


    public static int nppsThreshold_GT_16sc_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_16sc_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_16sc_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel);


    /**
     * <pre>
     * 32-bit floating point signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_32fNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel);


    /**
     * <pre>
     * 32-bit in place floating point signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_32f_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel);


    /**
     * <pre>
     * 32-bit floating point complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_32fcNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel);


    /**
     * <pre>
     * 32-bit in place floating point complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_32fc_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_32fc_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_32fc_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel);


    /**
     * <pre>
     * 64-bit floating point signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_64fNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel);


    /**
     * <pre>
     * 64-bit in place floating point signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_64f_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel);


    /**
     * <pre>
     * 64-bit floating point complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_64fcNative(pSrc, pDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel);


    /**
     * <pre>
     * 64-bit in place floating point complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GT_64fc_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel)
    {
        return JNpp.checkResult(nppsThreshold_GT_64fc_INative(pSrcDst, nLength, nLevel));
    }
    private static native int nppsThreshold_GT_64fc_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel);


    /**
     * <pre>
     * 16-bit signed short signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_16s(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        short nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_16sNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_16sNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        short nValue);


    /**
     * <pre>
     * 16-bit in place signed short signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_16s_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        short nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_16s_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_16s_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        short nValue);


    /**
     * <pre>
     * 16-bit signed short complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_16sc(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        Npp16sc nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_16scNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_16scNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        Npp16sc nValue);


    /**
     * <pre>
     * 16-bit in place signed short complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_16sc_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        Npp16sc nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_16sc_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_16sc_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        Npp16sc nValue);


    /**
     * <pre>
     * 32-bit floating point signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        float nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_32fNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        float nValue);


    /**
     * <pre>
     * 32-bit in place floating point signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        float nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_32f_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        float nValue);


    /**
     * <pre>
     * 32-bit floating point complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        Npp32fc nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_32fcNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        Npp32fc nValue);


    /**
     * <pre>
     * 32-bit in place floating point complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_32fc_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        Npp32fc nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_32fc_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_32fc_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        Npp32fc nValue);


    /**
     * <pre>
     * 64-bit floating point signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        double nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_64fNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        double nValue);


    /**
     * <pre>
     * 64-bit in place floating point signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        double nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_64f_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        double nValue);


    /**
     * <pre>
     * 64-bit floating point complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        Npp64fc nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_64fcNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        Npp64fc nValue);


    /**
     * <pre>
     * 64-bit in place floating point complex number signal NPP_CMP_LESS threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_LTVal_64fc_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        Npp64fc nValue)
    {
        return JNpp.checkResult(nppsThreshold_LTVal_64fc_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_LTVal_64fc_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        Npp64fc nValue);


    /**
     * <pre>
     * 16-bit signed short signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_16s(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        short nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_16sNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_16sNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        short nValue);


    /**
     * <pre>
     * 16-bit in place signed short signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_16s_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        short nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_16s_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_16s_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        short nValue);


    /**
     * <pre>
     * 16-bit signed short complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_16sc(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        Npp16sc nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_16scNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_16scNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short nLevel,
        Npp16sc nValue);


    /**
     * <pre>
     * 16-bit in place signed short complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_16sc_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        Npp16sc nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_16sc_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_16sc_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        short nLevel,
        Npp16sc nValue);


    /**
     * <pre>
     * 32-bit floating point signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        float nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_32fNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        float nValue);


    /**
     * <pre>
     * 32-bit in place floating point signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        float nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_32f_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        float nValue);


    /**
     * <pre>
     * 32-bit floating point complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        Npp32fc nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_32fcNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float nLevel,
        Npp32fc nValue);


    /**
     * <pre>
     * 32-bit in place floating point complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_32fc_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        Npp32fc nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_32fc_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_32fc_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nLevel,
        Npp32fc nValue);


    /**
     * <pre>
     * 64-bit floating point signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        double nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_64fNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        double nValue);


    /**
     * <pre>
     * 64-bit in place floating point signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        double nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_64f_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        double nValue);


    /**
     * <pre>
     * 64-bit floating point complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        Npp64fc nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_64fcNative(pSrc, pDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double nLevel,
        Npp64fc nValue);


    /**
     * <pre>
     * 64-bit in place floating point complex number signal NPP_CMP_GREATER threshold with constant level.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nLevel Constant threshold value (real part only and must be greater than 0) to be used to limit each signal sample
     * @param nValue Constant value to replace source value when threshold test is true.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsThreshold_GTVal_64fc_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        Npp64fc nValue)
    {
        return JNpp.checkResult(nppsThreshold_GTVal_64fc_INative(pSrcDst, nLength, nLevel, nValue));
    }
    private static native int nppsThreshold_GTVal_64fc_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength,
        double nLevel,
        Npp64fc nValue);


    public static int nppsAddC_8u_ISfs(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_8u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_8u_ISfsNative(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned charvector add constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_8u_Sfs(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_8u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_8u_SfsNative(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsAddC_16u_ISfs(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_16u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_16u_ISfsNative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short vector add constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_16u_Sfs(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_16u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_16u_SfsNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place  signal add constant, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_16s_ISfs(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_16s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_16s_ISfsNative(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    public static int nppsAddC_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_16s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary)signal add constant,
     * scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_16sc_ISfs(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_16sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_16sc_ISfsNative(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    public static int nppsAddC_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_16sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer in place signal add constant and scale.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_32s_ISfs(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_32s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_32s_ISfsNative(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    public static int nppsAddC_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_32s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit integer complex number (32 bit real, 32 bit imaginary) in place signal
     * add constant and scale.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_32sc_ISfs(
        Npp32sc nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_32sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_32sc_ISfsNative(
        Npp32sc nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit integer complex number (32 bit real, 32 bit imaginary) signal add constant
     * and scale.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_32sc_Sfs(
        TypedPointer<Npp32s> pSrc,
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddC_32sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddC_32sc_SfsNative(
        TypedPointer<Npp32s> pSrc,
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point in place signal add constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_32f_I(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddC_32f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsAddC_32f_INative(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal add constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_32f(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddC_32fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsAddC_32fNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) in
     * place signal add constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_32fc_I(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddC_32fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsAddC_32fc_INative(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    public static int nppsAddC_32fc(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddC_32fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsAddC_32fcNative(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point, in place signal add constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param nLength Length of the vectors, number of items.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_64f_I(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddC_64f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsAddC_64f_INative(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating pointsignal add constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_64f(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddC_64fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsAddC_64fNative(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) in
     * place signal add constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be added to each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddC_64fc_I(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddC_64fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsAddC_64fc_INative(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    public static int nppsAddC_64fc(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddC_64fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsAddC_64fcNative(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal add product of signal times constant to destination signal.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddProductC_32f(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddProductC_32fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsAddProductC_32fNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    public static int nppsMulC_8u_ISfs(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_8u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_8u_ISfsNative(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    public static int nppsMulC_8u_Sfs(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_8u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_8u_SfsNative(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsMulC_16u_ISfs(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_16u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_16u_ISfsNative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal times constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_16u_Sfs(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_16u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_16u_SfsNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal times constant, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_16s_ISfs(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_16s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_16s_ISfsNative(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal times constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_16s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary)signal times constant,
     * scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_16sc_ISfs(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_16sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_16sc_ISfsNative(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary)signal times constant,
     * scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_16sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer in place signal times constant and scale.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_32s_ISfs(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_32s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_32s_ISfsNative(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal times constant and scale.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_32s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit integer complex number (32 bit real, 32 bit imaginary) in place signal
     * times constant and scale.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_32sc_ISfs(
        Npp32sc nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_32sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_32sc_ISfsNative(
        Npp32sc nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit integer complex number (32 bit real, 32 bit imaginary) signal times constant
     * and scale.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_32sc_Sfs(
        TypedPointer<Npp32s> pSrc,
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_32sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_32sc_SfsNative(
        TypedPointer<Npp32s> pSrc,
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsMulC_32f_I(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_32f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsMulC_32f_INative(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal times constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_32f(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_32fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsMulC_32fNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal times constant with output converted to 16-bit signed integer.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_Low_32f16s(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_Low_32f16sNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsMulC_Low_32f16sNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal times constant with output converted to 16-bit signed integer
     * with scaling and saturation of output result.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_32f16s_Sfs(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_32f16s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_32f16s_SfsNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) in
     * place signal times constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_32fc_I(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_32fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsMulC_32fc_INative(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) signal
     * times constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_32fc(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_32fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsMulC_32fcNative(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point, in place signal times constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param nLength Length of the vectors, number of items.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_64f_I(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_64f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsMulC_64f_INative(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal times constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_64f(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_64fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsMulC_64fNative(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal times constant with in place conversion to 64-bit signed integer
     * and with scaling and saturation of output result.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_64f64s_ISfs(
        double nValue,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMulC_64f64s_ISfsNative(nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMulC_64f64s_ISfsNative(
        double nValue,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) in
     * place signal times constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_64fc_I(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_64fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsMulC_64fc_INative(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) signal
     * times constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be multiplied by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMulC_64fc(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMulC_64fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsMulC_64fcNative(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal subtract constant,
     * scale, then clamp to saturated value
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_8u_ISfs(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_8u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_8u_ISfsNative(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned char signal subtract constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_8u_Sfs(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_8u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_8u_SfsNative(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short in place signal subtract constant, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_16u_ISfs(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_16u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_16u_ISfsNative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal subtract constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_16u_Sfs(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_16u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_16u_SfsNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal subtract constant, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_16s_ISfs(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_16s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_16s_ISfsNative(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    public static int nppsSubC_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_16s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary) signal subtract constant,
     * scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_16sc_ISfs(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_16sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_16sc_ISfsNative(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary) signal subtract constant,
     * scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_16sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer in place signal subtract constant and scale.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_32s_ISfs(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_32s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_32s_ISfsNative(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal subtract constant and scale.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_32s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit integer complex number (32 bit real, 32 bit imaginary) in place signal
     * subtract constant and scale.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_32sc_ISfs(
        Npp32sc nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_32sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_32sc_ISfsNative(
        Npp32sc nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit integer complex number (32 bit real, 32 bit imaginary)signal subtract constant
     * and scale.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_32sc_Sfs(
        TypedPointer<Npp32s> pSrc,
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubC_32sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubC_32sc_SfsNative(
        TypedPointer<Npp32s> pSrc,
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point in place signal subtract constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_32f_I(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubC_32f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsSubC_32f_INative(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal subtract constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_32f(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubC_32fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsSubC_32fNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) in
     * place signal subtract constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_32fc_I(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubC_32fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsSubC_32fc_INative(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) signal
     * subtract constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_32fc(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubC_32fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsSubC_32fcNative(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point, in place signal subtract constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength Length of the vectors, number of items.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_64f_I(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubC_64f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsSubC_64f_INative(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal subtract constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_64f(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubC_64fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsSubC_64fNative(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) in
     * place signal subtract constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_64fc_I(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubC_64fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsSubC_64fc_INative(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) signal
     * subtract constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be subtracted from each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubC_64fc(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubC_64fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsSubC_64fcNative(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal subtract from constant,
     * scale, then clamp to saturated value
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_8u_ISfs(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_8u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_8u_ISfsNative(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned char signal subtract from constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_8u_Sfs(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_8u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_8u_SfsNative(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short in place signal subtract from constant, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_16u_ISfs(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_16u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_16u_ISfsNative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal subtract from constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_16u_Sfs(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_16u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_16u_SfsNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal subtract from constant, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_16s_ISfs(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_16s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_16s_ISfsNative(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    public static int nppsSubCRev_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_16s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary) signal subtract from constant,
     * scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_16sc_ISfs(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_16sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_16sc_ISfsNative(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary) signal subtract from constant,
     * scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_16sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer in place signal subtract from constant and scale.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_32s_ISfs(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_32s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_32s_ISfsNative(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integersignal subtract from constant and scale.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_32s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit integer complex number (32 bit real, 32 bit imaginary) in place signal
     * subtract from constant and scale.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_32sc_ISfs(
        Npp32sc nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_32sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_32sc_ISfsNative(
        Npp32sc nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit integer complex number (32 bit real, 32 bit imaginary) signal subtract from constant
     * and scale.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_32sc_Sfs(
        TypedPointer<Npp32s> pSrc,
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSubCRev_32sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSubCRev_32sc_SfsNative(
        TypedPointer<Npp32s> pSrc,
        Npp32sc nValue,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point in place signal subtract from constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_32f_I(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubCRev_32f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsSubCRev_32f_INative(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal subtract from constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_32f(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubCRev_32fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsSubCRev_32fNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) in
     * place signal subtract from constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_32fc_I(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubCRev_32fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsSubCRev_32fc_INative(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) signal
     * subtract from constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_32fc(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubCRev_32fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsSubCRev_32fcNative(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point, in place signal subtract from constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength Length of the vectors, number of items.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_64f_I(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubCRev_64f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsSubCRev_64f_INative(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal subtract from constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_64f(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubCRev_64fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsSubCRev_64fNative(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) in
     * place signal subtract from constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_64fc_I(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubCRev_64fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsSubCRev_64fc_INative(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) signal
     * subtract from constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value each vector element is to be subtracted from
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSubCRev_64fc(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSubCRev_64fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsSubCRev_64fcNative(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal divided by constant,
     * scale, then clamp to saturated value
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_8u_ISfs(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDivC_8u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDivC_8u_ISfsNative(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned char signal divided by constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_8u_Sfs(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDivC_8u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDivC_8u_SfsNative(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short in place signal divided by constant, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_16u_ISfs(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDivC_16u_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDivC_16u_ISfsNative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal divided by constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_16u_Sfs(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDivC_16u_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDivC_16u_SfsNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal divided by constant, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_16s_ISfs(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDivC_16s_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDivC_16s_ISfsNative(
        short nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal divided by constant, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDivC_16s_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDivC_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        short nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary)signal divided by constant,
     * scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_16sc_ISfs(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDivC_16sc_ISfsNative(nValue, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDivC_16sc_ISfsNative(
        Npp16sc nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit integer complex number (16 bit real, 16 bit imaginary) signal divided by constant,
     * scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDivC_16sc_SfsNative(pSrc, nValue, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDivC_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        Npp16sc nValue,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point in place signal divided by constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_32f_I(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivC_32f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsDivC_32f_INative(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal divided by constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_32f(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivC_32fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsDivC_32fNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) in
     * place signal divided by constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_32fc_I(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivC_32fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsDivC_32fc_INative(
        Npp32fc nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point complex number (32 bit real, 32 bit imaginary) signal
     * divided by constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_32fc(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivC_32fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsDivC_32fcNative(
        TypedPointer<Npp32f> pSrc,
        Npp32fc nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point in place signal divided by constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param nLength Length of the vectors, number of items.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_64f_I(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivC_64f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsDivC_64f_INative(
        double nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal divided by constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_64f(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivC_64fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsDivC_64fNative(
        TypedPointer<Npp64f> pSrc,
        double nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) in
     * place signal divided by constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_64fc_I(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivC_64fc_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsDivC_64fc_INative(
        Npp64fc nValue,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point complex number (64 bit real, 64 bit imaginary) signal
     * divided by constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided into each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivC_64fc(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivC_64fcNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsDivC_64fcNative(
        TypedPointer<Npp64f> pSrc,
        Npp64fc nValue,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /** @} signal_divc */
    /**
     * <pre>
     * @defgroup signal_divcrev DivCRev
     *
     * Divides a constant by each sample of a signal.
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * 16-bit unsigned short in place constant divided by signal, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided by each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivCRev_16u_I(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivCRev_16u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsDivCRev_16u_INative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal divided by constant, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivCRev_16u(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivCRev_16uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsDivCRev_16uNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point in place constant divided by signal.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be divided by each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivCRev_32f_I(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivCRev_32f_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsDivCRev_32f_INative(
        float nValue,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point constant divided by signal.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be divided by each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDivCRev_32f(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDivCRev_32fNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsDivCRev_32fNative(
        TypedPointer<Npp32f> pSrc,
        float nValue,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal add signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be added to signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16s(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_16sNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_16sNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength);


    public static int nppsAdd_16u(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_16uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_16uNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned int signal add signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be added to signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_32u(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_32uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_32uNative(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal add signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be added to signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_32fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal add signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be added to signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_64fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal add signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be added to signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_32fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal add signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be added to signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_64fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal add signal with 16-bit unsigned result,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be added to signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_8u16u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_8u16uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_8u16uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal add signal with 32-bit floating point result,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be added to signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16s32f(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_16s32fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAdd_16s32fNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char add signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be added to signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_8u_Sfs(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_8u_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_8u_SfsNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short add signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be added to signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16u_Sfs(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_16u_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_16u_SfsNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short add signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be added to signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_16s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_16s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer add signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be added to signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_32s_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_32s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_32s_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 64-bit signed integer add signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be added to signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_64s_Sfs(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_64s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_64s_SfsNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed complex short add signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be added to signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16sc_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_16sc_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed complex integer add signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be added to signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_32sc_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_32sc_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_32sc_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal add signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16s_I(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_16s_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAdd_16s_INative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point in place signal add signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_32f_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_32f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAdd_32f_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point in place signal add signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_64f_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_64f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAdd_64f_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    public static int nppsAdd_32fc_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_32fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAdd_32fc_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point in place signal add signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_64fc_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_64fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAdd_64fc_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16/32-bit signed short in place signal add signal with 32-bit signed integer results,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16s32s_I(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAdd_16s32s_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAdd_16s32s_INative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal add signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_8u_ISfs(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_8u_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_8u_ISfsNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short in place signal add signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16u_ISfs(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_16u_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_16u_ISfsNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal add signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16s_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_16s_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_16s_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer in place signal add signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_32s_ISfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_32s_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_32s_ISfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short in place signal add signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_16sc_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_16sc_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_16sc_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit complex signed integer in place signal add signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be added to signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAdd_32sc_ISfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAdd_32sc_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsAdd_32sc_ISfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * @defgroup signal_addproduct AddProduct
     *
     * Adds sample by sample product of two signals to the destination signal.
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * 32-bit floating point signal add product of source signal times destination signal to destination signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer. product of source1 and source2 signal elements to be added to destination elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddProduct_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddProduct_32fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAddProduct_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal add product of source signal times destination signal to destination signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer. product of source1 and source2 signal elements to be added to destination elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddProduct_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddProduct_64fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAddProduct_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal add product of source signal times destination signal to destination signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer. product of source1 and source2 signal elements to be added to destination elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddProduct_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddProduct_32fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAddProduct_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal add product of source signal times destination signal to destination signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer. product of source1 and source2 signal elements to be added to destination elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddProduct_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAddProduct_64fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAddProduct_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal add product of source signal1 times source signal2 to destination signal,
     * with scaling, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer. product of source1 and source2 signal elements to be added to destination elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddProduct_16s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddProduct_16s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddProduct_16s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed short signal add product of source signal1 times source signal2 to destination signal,
     * with scaling, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer. product of source1 and source2 signal elements to be added to destination elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAddProduct_32s_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddProduct_32s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddProduct_32s_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsAddProduct_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsAddProduct_16s32s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsAddProduct_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal times signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16s(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_16sNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsMul_16sNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal times signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_32fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsMul_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal times signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_64fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsMul_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal times signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_32fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsMul_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal times signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_64fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsMul_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal times signal with 16-bit unsigned result,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_8u16u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_8u16uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsMul_8u16uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal times signal with 32-bit floating point result,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16s32f(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_16s32fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsMul_16s32fNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal times 32-bit complex floating point signal with complex 32-bit floating point result,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32f32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_32f32fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsMul_32f32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal times signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_8u_Sfs(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_8u_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_8u_SfsNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal time signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16u_Sfs(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_16u_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_16u_SfsNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal times signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_16s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_16s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal times signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32s_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_32s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_32s_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed complex short signal times signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16sc_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_16sc_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed complex integer signal times signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32sc_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_32sc_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_32sc_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal times 16-bit signed short signal, scale, then clamp to 16-bit signed saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16u16s_Sfs(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_16u16s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_16u16s_SfsNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal times signal, scale, then clamp to 32-bit signed saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_16s32s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal times 32-bit complex signed integer signal, scale, then clamp to 32-bit complex integer saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32s32sc_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_32s32sc_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_32s32sc_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal times signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal2 elements to be multiplied by signal1 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_Low_32s_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_Low_32s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_Low_32s_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal times signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16s_I(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_16s_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMul_16s_INative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point in place signal times signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32f_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_32f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMul_32f_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point in place signal times signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_64f_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_64f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMul_64f_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point in place signal times signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32fc_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_32fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMul_32fc_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point in place signal times signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_64fc_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_64fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMul_64fc_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point in place signal times 32-bit floating point signal,
     * then clamp to 32-bit complex floating point saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32f32fc_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMul_32f32fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMul_32f32fc_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal times signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_8u_ISfs(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_8u_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_8u_ISfsNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short in place signal times signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16u_ISfs(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_16u_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_16u_ISfsNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal times signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16s_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_16s_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_16s_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer in place signal times signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32s_ISfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_32s_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_32s_ISfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short in place signal times signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_16sc_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_16sc_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_16sc_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit complex signed integer in place signal times signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be multiplied by signal1 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMul_32sc_ISfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_32sc_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_32sc_ISfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    public static int nppsMul_32s32sc_ISfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsMul_32s32sc_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsMul_32s32sc_ISfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16s(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_16sNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsSub_16sNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_32fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsSub_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_64fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsSub_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_32fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsSub_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_64fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsSub_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal subtract 16-bit signed short signal,
     * then clamp and convert to 32-bit floating point saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16s32f(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_16s32fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsSub_16s32fNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal subtract signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 elements to be subtracted from signal2 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_8u_Sfs(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_8u_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_8u_SfsNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal subtract signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 elements to be subtracted from signal2 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16u_Sfs(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_16u_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_16u_SfsNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal subtract signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 elements to be subtracted from signal2 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_16s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_16s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal subtract signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 elements to be subtracted from signal2 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_32s_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_32s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_32s_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed complex short signal subtract signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 elements to be subtracted from signal2 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16sc_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_16sc_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed complex integer signal subtract signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 elements to be subtracted from signal2 elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_32sc_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_32sc_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_32sc_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16s_I(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_16s_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsSub_16s_INative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point in place signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_32f_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_32f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsSub_32f_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point in place signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_64f_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_64f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsSub_64f_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point in place signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_32fc_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_32fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsSub_32fc_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point in place signal subtract signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_64fc_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSub_64fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsSub_64fc_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal subtract signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_8u_ISfs(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_8u_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_8u_ISfsNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short in place signal subtract signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16u_ISfs(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_16u_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_16u_ISfsNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal subtract signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16s_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_16s_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_16s_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer in place signal subtract signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_32s_ISfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_32s_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_32s_ISfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short in place signal subtract signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_16sc_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_16sc_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_16sc_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit complex signed integer in place signal subtract signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 elements to be subtracted from signal2 elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSub_32sc_ISfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSub_32sc_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSub_32sc_ISfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned char signal divide signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_8u_Sfs(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_8u_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_8u_SfsNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal divide signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_16u_Sfs(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_16u_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_16u_SfsNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal divide signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_16s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_16s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_16s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal divide signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_32s_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_32s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_32s_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed complex short signal divide signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_16sc_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_16sc_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal divided by 16-bit signed short signal, scale, then clamp to 16-bit signed short saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_32s16s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_32s16s_SfsNative(pSrc1, pSrc2, pDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_32s16s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point signal divide signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDiv_32fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsDiv_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal divide signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDiv_64fNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsDiv_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal divide signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDiv_32fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsDiv_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal divide signal,
     * then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDiv_64fcNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsDiv_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal divide signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_8u_ISfs(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_8u_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_8u_ISfsNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short in place signal divide signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_16u_ISfs(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_16u_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_16u_ISfsNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal divide signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_16s_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_16s_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_16s_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short in place signal divide signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_16sc_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_16sc_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_16sc_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer in place signal divide signal, with scaling,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_32s_ISfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_32s_ISfsNative(pSrc, pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsDiv_32s_ISfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point in place signal divide signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_32f_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDiv_32f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsDiv_32f_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point in place signal divide signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_64f_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDiv_64f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsDiv_64f_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point in place signal divide signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_32fc_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDiv_32fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsDiv_32fc_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point in place signal divide signal,
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_64fc_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsDiv_64fc_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsDiv_64fc_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal divide signal, scale, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nRndMode various rounding modes.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_Round_8u_Sfs(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nRndMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_Round_8u_SfsNative(pSrc1, pSrc2, pDst, nLength, nRndMode, nScaleFactor));
    }
    private static native int nppsDiv_Round_8u_SfsNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nRndMode,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal divide signal, scale, round, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nRndMode various rounding modes.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_Round_16u_Sfs(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nRndMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_Round_16u_SfsNative(pSrc1, pSrc2, pDst, nLength, nRndMode, nScaleFactor));
    }
    private static native int nppsDiv_Round_16u_SfsNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nRndMode,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal divide signal, scale, round, then clamp to saturated value.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer, signal1 divisor elements to be divided into signal2 dividend elements.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nRndMode various rounding modes.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_Round_16s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nRndMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_Round_16s_SfsNative(pSrc1, pSrc2, pDst, nLength, nRndMode, nScaleFactor));
    }
    private static native int nppsDiv_Round_16s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nRndMode,
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned char in place signal divide signal, with scaling, rounding
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @param nRndMode various rounding modes.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_Round_8u_ISfs(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nRndMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_Round_8u_ISfsNative(pSrc, pSrcDst, nLength, nRndMode, nScaleFactor));
    }
    private static native int nppsDiv_Round_8u_ISfsNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nRndMode,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short in place signal divide signal, with scaling, rounding
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @param nRndMode various rounding modes.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_Round_16u_ISfs(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nRndMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_Round_16u_ISfsNative(pSrc, pSrcDst, nLength, nRndMode, nScaleFactor));
    }
    private static native int nppsDiv_Round_16u_ISfsNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nRndMode,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short in place signal divide signal, with scaling, rounding
     * then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal1 divisor elements to be divided into signal2 dividend elements
     * @param nLength \ref length_specification.
     * @param nRndMode various rounding modes.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDiv_Round_16s_ISfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nRndMode,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsDiv_Round_16s_ISfsNative(pSrc, pSrcDst, nLength, nRndMode, nScaleFactor));
    }
    private static native int nppsDiv_Round_16s_ISfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nRndMode,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal absolute value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAbs_16s(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAbs_16sNative(pSrc, pDst, nLength));
    }
    private static native int nppsAbs_16sNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed integer signal absolute value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAbs_32s(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAbs_32sNative(pSrc, pDst, nLength));
    }
    private static native int nppsAbs_32sNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal absolute value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAbs_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAbs_32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsAbs_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal absolute value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAbs_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAbs_64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsAbs_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal absolute value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAbs_16s_I(
        TypedPointer<Npp16s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAbs_16s_INative(pSrcDst, nLength));
    }
    private static native int nppsAbs_16s_INative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed integer signal absolute value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAbs_32s_I(
        TypedPointer<Npp32s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAbs_32s_INative(pSrcDst, nLength));
    }
    private static native int nppsAbs_32s_INative(
        TypedPointer<Npp32s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal absolute value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAbs_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAbs_32f_INative(pSrcDst, nLength));
    }
    private static native int nppsAbs_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal absolute value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAbs_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAbs_64f_INative(pSrcDst, nLength));
    }
    private static native int nppsAbs_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /** @} signal_abs */
    /**
     * <pre>
     * @defgroup signal_square Sqr
     *
     * Squares each sample of a signal.
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * 32-bit floating point signal squared.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqr_32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsSqr_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal squared.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqr_64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsSqr_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal squared.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqr_32fcNative(pSrc, pDst, nLength));
    }
    private static native int nppsSqr_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal squared.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqr_64fcNative(pSrc, pDst, nLength));
    }
    private static native int nppsSqr_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal squared.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqr_32f_INative(pSrcDst, nLength));
    }
    private static native int nppsSqr_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal squared.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqr_64f_INative(pSrcDst, nLength));
    }
    private static native int nppsSqr_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal squared.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_32fc_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqr_32fc_INative(pSrcDst, nLength));
    }
    private static native int nppsSqr_32fc_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal squared.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_64fc_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqr_64fc_INative(pSrcDst, nLength));
    }
    private static native int nppsSqr_64fc_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal squared, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_8u_Sfs(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqr_8u_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqr_8u_SfsNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal squared, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_16u_Sfs(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqr_16u_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqr_16u_SfsNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    public static int nppsSqr_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqr_16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqr_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short signal squared, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqr_16sc_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqr_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned char signal squared, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_8u_ISfs(
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqr_8u_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqr_8u_ISfsNative(
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal squared, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_16u_ISfs(
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqr_16u_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqr_16u_ISfsNative(
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal squared, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_16s_ISfs(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqr_16s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqr_16s_ISfsNative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short signal squared, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqr_16sc_ISfs(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqr_16sc_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqr_16sc_ISfsNative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point signal square root.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqrt_32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsSqrt_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal square root.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqrt_64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsSqrt_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal square root.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqrt_32fcNative(pSrc, pDst, nLength));
    }
    private static native int nppsSqrt_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal square root.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqrt_64fcNative(pSrc, pDst, nLength));
    }
    private static native int nppsSqrt_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal square root.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqrt_32f_INative(pSrcDst, nLength));
    }
    private static native int nppsSqrt_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal square root.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqrt_64f_INative(pSrcDst, nLength));
    }
    private static native int nppsSqrt_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit complex floating point signal square root.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_32fc_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqrt_32fc_INative(pSrcDst, nLength));
    }
    private static native int nppsSqrt_32fc_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit complex floating point signal square root.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_64fc_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsSqrt_64fc_INative(pSrcDst, nLength));
    }
    private static native int nppsSqrt_64fc_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal square root, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_8u_Sfs(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_8u_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_8u_SfsNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal square root, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_16u_Sfs(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_16u_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_16u_SfsNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal square root, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short signal square root, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_16sc_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 64-bit signed integer signal square root, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_64s_Sfs(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_64s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_64s_SfsNative(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal square root, scale, then clamp to 16-bit signed integer saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_32s16s_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_32s16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_32s16s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 64-bit signed integer signal square root, scale, then clamp to 16-bit signed integer saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_64s16s_Sfs(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_64s16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_64s16s_SfsNative(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 8-bit unsigned char signal square root, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_8u_ISfs(
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_8u_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_8u_ISfsNative(
        TypedPointer<Npp8u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit unsigned short signal square root, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_16u_ISfs(
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_16u_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_16u_ISfsNative(
        TypedPointer<Npp16u> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal square root, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_16s_ISfs(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_16s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_16s_ISfsNative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short signal square root, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_16sc_ISfs(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_16sc_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_16sc_ISfsNative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 64-bit signed integer signal square root, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSqrt_64s_ISfs(
        TypedPointer<Npp64s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsSqrt_64s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsSqrt_64s_ISfsNative(
        TypedPointer<Npp64s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point signal cube root.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCubrt_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsCubrt_32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsCubrt_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed integer signal cube root, scale, then clamp to 16-bit signed integer saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCubrt_32s16s_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsCubrt_32s16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsCubrt_32s16s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point signal exponent.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsExp_32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsExp_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal exponent.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsExp_64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsExp_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal exponent with 64-bit floating point result.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_32f64f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsExp_32f64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsExp_32f64fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal exponent.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsExp_32f_INative(pSrcDst, nLength));
    }
    private static native int nppsExp_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal exponent.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsExp_64f_INative(pSrcDst, nLength));
    }
    private static native int nppsExp_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal exponent, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsExp_16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsExp_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal exponent, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsExp_32s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsExp_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 64-bit signed integer signal exponent, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_64s_Sfs(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsExp_64s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsExp_64s_SfsNative(
        TypedPointer<Npp64s> pSrc,
        TypedPointer<Npp64s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal exponent, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_16s_ISfs(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsExp_16s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsExp_16s_ISfsNative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal exponent, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_32s_ISfs(
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsExp_32s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsExp_32s_ISfsNative(
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 64-bit signed integer signal exponent, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsExp_64s_ISfs(
        TypedPointer<Npp64s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsExp_64s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsExp_64s_ISfsNative(
        TypedPointer<Npp64s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /** @} signal_exp */
    /**
     * <pre>
     * @defgroup signal_ln Ln
     *
     * Natural logarithm of each sample of a signal.
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * 32-bit floating point signal natural logarithm.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLn_32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsLn_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal natural logarithm.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLn_64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsLn_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal natural logarithm with 32-bit floating point result.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_64f32f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLn_64f32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsLn_64f32fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal natural logarithm.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLn_32f_INative(pSrcDst, nLength));
    }
    private static native int nppsLn_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal natural logarithm.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLn_64f_INative(pSrcDst, nLength));
    }
    private static native int nppsLn_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal natural logarithm, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsLn_16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsLn_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal natural logarithm, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsLn_32s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsLn_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal natural logarithm, scale, then clamp to 16-bit signed short saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_32s16s_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsLn_32s16s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int nppsLn_32s16s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit signed short signal natural logarithm, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_16s_ISfs(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsLn_16s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsLn_16s_ISfsNative(
        TypedPointer<Npp16s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal natural logarithm, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLn_32s_ISfs(
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsLn_32s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int nppsLn_32s_ISfsNative(
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal 10 times base 10 logarithm, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int npps10Log10_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(npps10Log10_32s_SfsNative(pSrc, pDst, nLength, nScaleFactor));
    }
    private static native int npps10Log10_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit signed integer signal 10 times base 10 logarithm, scale, then clamp to saturated value.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int npps10Log10_32s_ISfs(
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor)
    {
        return JNpp.checkResult(npps10Log10_32s_ISfsNative(pSrcDst, nLength, nScaleFactor));
    }
    private static native int npps10Log10_32s_ISfsNative(
        TypedPointer<Npp32s> pSrcDst,
        int nLength,
        int nScaleFactor);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for 32f SumLn.
     * This primitive provides the correct buffer size for nppsSumLn_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumLnGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsSumLnGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsSumLnGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 32-bit floating point signal sum natural logarithm.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSumLn_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSumLn_32fNative(pSrc, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsSumLn_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for 64f SumLn.
     * This primitive provides the correct buffer size for nppsSumLn_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumLnGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsSumLnGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsSumLnGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 64-bit floating point signal sum natural logarithm.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSumLn_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSumLn_64fNative(pSrc, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsSumLn_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for 32f64f SumLn.
     * This primitive provides the correct buffer size for nppsSumLn_32f64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumLnGetBufferSize_32f64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsSumLnGetBufferSize_32f64fNative(nLength, hpBufferSize));
    }
    private static native int nppsSumLnGetBufferSize_32f64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit flaoting point input, 64-bit floating point output signal sum natural logarithm.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSumLn_32f64f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSumLn_32f64fNative(pSrc, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsSumLn_32f64fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for 16s32f SumLn.
     * This primitive provides the correct buffer size for nppsSumLn_16s32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumLnGetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsSumLnGetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsSumLnGetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 16-bit signed short integer input, 32-bit floating point output signal sum natural logarithm.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSumLn_16s32f(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSumLn_16s32fNative(pSrc, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsSumLn_16s32fNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /** @} signal_sumln */
    /**
     * <pre>
     * @defgroup signal_inversetan Arctan
     *
     * Inverse tangent of each sample of a signal.
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * 32-bit floating point signal inverse tangent.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsArctan_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsArctan_32fNative(pSrc, pDst, nLength));
    }
    private static native int nppsArctan_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal inverse tangent.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsArctan_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsArctan_64fNative(pSrc, pDst, nLength));
    }
    private static native int nppsArctan_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal inverse tangent.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsArctan_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsArctan_32f_INative(pSrcDst, nLength));
    }
    private static native int nppsArctan_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 64-bit floating point signal inverse tangent.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsArctan_64f_I(
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsArctan_64f_INative(pSrcDst, nLength));
    }
    private static native int nppsArctan_64f_INative(
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point signal normalize.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param vSub value subtracted from each signal element before division
     * @param vDiv divisor of post-subtracted signal element dividend
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormalize_32f(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float vSub,
        float vDiv)
    {
        return JNpp.checkResult(nppsNormalize_32fNative(pSrc, pDst, nLength, vSub, vDiv));
    }
    private static native int nppsNormalize_32fNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        float vSub,
        float vDiv);


    public static int nppsNormalize_32fc(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        Npp32fc vSub,
        float vDiv)
    {
        return JNpp.checkResult(nppsNormalize_32fcNative(pSrc, pDst, nLength, vSub, vDiv));
    }
    private static native int nppsNormalize_32fcNative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pDst,
        int nLength,
        Npp32fc vSub,
        float vDiv);


    /**
     * <pre>
     * 64-bit floating point signal normalize.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param vSub value subtracted from each signal element before division
     * @param vDiv divisor of post-subtracted signal element dividend
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormalize_64f(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double vSub,
        double vDiv)
    {
        return JNpp.checkResult(nppsNormalize_64fNative(pSrc, pDst, nLength, vSub, vDiv));
    }
    private static native int nppsNormalize_64fNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        double vSub,
        double vDiv);


    /**
     * <pre>
     * 64-bit complex floating point signal normalize.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param vSub value subtracted from each signal element before division
     * @param vDiv divisor of post-subtracted signal element dividend
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormalize_64fc(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        Npp64fc vSub,
        double vDiv)
    {
        return JNpp.checkResult(nppsNormalize_64fcNative(pSrc, pDst, nLength, vSub, vDiv));
    }
    private static native int nppsNormalize_64fcNative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pDst,
        int nLength,
        Npp64fc vSub,
        double vDiv);


    /**
     * <pre>
     * 16-bit signed short signal normalize, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param vSub value subtracted from each signal element before division
     * @param vDiv divisor of post-subtracted signal element dividend
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormalize_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short vSub,
        int vDiv,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsNormalize_16s_SfsNative(pSrc, pDst, nLength, vSub, vDiv, nScaleFactor));
    }
    private static native int nppsNormalize_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        short vSub,
        int vDiv,
        int nScaleFactor);


    /**
     * <pre>
     * 16-bit complex signed short signal normalize, scale, then clamp to saturated value.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @param vSub value subtracted from each signal element before division
     * @param vDiv divisor of post-subtracted signal element dividend
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormalize_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        Npp16sc vSub,
        int vDiv,
        int nScaleFactor)
    {
        return JNpp.checkResult(nppsNormalize_16sc_SfsNative(pSrc, pDst, nLength, vSub, vDiv, nScaleFactor));
    }
    private static native int nppsNormalize_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pDst,
        int nLength,
        Npp16sc vSub,
        int vDiv,
        int nScaleFactor);


    /**
     * <pre>
     * 32-bit floating point signal Cauchy error calculation.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nParam constant used in Cauchy formula
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCauchy_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nParam)
    {
        return JNpp.checkResult(nppsCauchy_32f_INative(pSrcDst, nLength, nParam));
    }
    private static native int nppsCauchy_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nParam);


    /**
     * <pre>
     * 32-bit floating point signal Cauchy first derivative.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @param nParam constant used in Cauchy formula
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCauchyD_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nParam)
    {
        return JNpp.checkResult(nppsCauchyD_32f_INative(pSrcDst, nLength, nParam));
    }
    private static native int nppsCauchyD_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        int nLength,
        float nParam);


    /**
     * <pre>
     * 32-bit floating point signal Cauchy first and second derivatives.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param pD2FVal \ref source_signal_pointer. This signal contains the second derivative
     *      of the source signal.
     * @param nLength \ref length_specification.
     * @param nParam constant used in Cauchy formula
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCauchyDD2_32f_I(
        TypedPointer<Npp32f> pSrcDst,
        TypedPointer<Npp32f> pD2FVal,
        int nLength,
        float nParam)
    {
        return JNpp.checkResult(nppsCauchyDD2_32f_INative(pSrcDst, pD2FVal, nLength, nParam));
    }
    private static native int nppsCauchyDD2_32f_INative(
        TypedPointer<Npp32f> pSrcDst,
        TypedPointer<Npp32f> pD2FVal,
        int nLength,
        float nParam);


    /**
     * <pre>
     * 8-bit unsigned char signal and with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be anded with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAndC_8u(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAndC_8uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsAndC_8uNative(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal and with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be anded with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAndC_16u(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAndC_16uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsAndC_16uNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer signal and with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be anded with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAndC_32u(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAndC_32uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsAndC_32uNative(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal and with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be anded with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAndC_8u_I(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAndC_8u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsAndC_8u_INative(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place signal and with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be anded with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAndC_16u_I(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAndC_16u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsAndC_16u_INative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned signed integer in place signal and with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be anded with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAndC_32u_I(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAndC_32u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsAndC_32u_INative(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal and with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be anded with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAnd_8u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAnd_8uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAnd_8uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal and with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be anded with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAnd_16u(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAnd_16uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAnd_16uNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer signal and with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be anded with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAnd_32u(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAnd_32uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsAnd_32uNative(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal and with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be anded with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAnd_8u_I(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAnd_8u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAnd_8u_INative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place signal and with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be anded with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAnd_16u_I(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAnd_16u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAnd_16u_INative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer in place signal and with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be anded with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAnd_32u_I(
        TypedPointer<Npp32u> pSrc,
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsAnd_32u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsAnd_32u_INative(
        TypedPointer<Npp32u> pSrc,
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal or with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be ored with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOrC_8u(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOrC_8uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsOrC_8uNative(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal or with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be ored with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOrC_16u(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOrC_16uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsOrC_16uNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer signal or with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be ored with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOrC_32u(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOrC_32uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsOrC_32uNative(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal or with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be ored with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOrC_8u_I(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOrC_8u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsOrC_8u_INative(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place signal or with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be ored with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOrC_16u_I(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOrC_16u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsOrC_16u_INative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned signed integer in place signal or with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be ored with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOrC_32u_I(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOrC_32u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsOrC_32u_INative(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal or with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be ored with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOr_8u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOr_8uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsOr_8uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal or with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be ored with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOr_16u(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOr_16uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsOr_16uNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer signal or with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be ored with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOr_32u(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOr_32uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsOr_32uNative(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal or with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be ored with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOr_8u_I(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOr_8u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsOr_8u_INative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place signal or with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be ored with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOr_16u_I(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOr_16u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsOr_16u_INative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer in place signal or with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be ored with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsOr_32u_I(
        TypedPointer<Npp32u> pSrc,
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsOr_32u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsOr_32u_INative(
        TypedPointer<Npp32u> pSrc,
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal exclusive or with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be exclusive ored with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXorC_8u(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXorC_8uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsXorC_8uNative(
        TypedPointer<Npp8u> pSrc,
        byte nValue,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal exclusive or with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be exclusive ored with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXorC_16u(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXorC_16uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsXorC_16uNative(
        TypedPointer<Npp16u> pSrc,
        short nValue,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer signal exclusive or with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be exclusive ored with each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXorC_32u(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXorC_32uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsXorC_32uNative(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal exclusive or with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be exclusive ored with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXorC_8u_I(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXorC_8u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsXorC_8u_INative(
        byte nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place signal exclusive or with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be exclusive ored with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXorC_16u_I(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXorC_16u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsXorC_16u_INative(
        short nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned signed integer in place signal exclusive or with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be exclusive ored with each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXorC_32u_I(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXorC_32u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsXorC_32u_INative(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal exclusive or with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be exclusive ored with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXor_8u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXor_8uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsXor_8uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal exclusive or with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be exclusive ored with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXor_16u(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXor_16uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsXor_16uNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer signal exclusive or with signal.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer. signal2 elements to be exclusive ored with signal1 elements
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXor_32u(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXor_32uNative(pSrc1, pSrc2, pDst, nLength));
    }
    private static native int nppsXor_32uNative(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal exclusive or with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be exclusive ored with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXor_8u_I(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXor_8u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsXor_8u_INative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place signal exclusive or with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be exclusive ored with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXor_16u_I(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXor_16u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsXor_16u_INative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer in place signal exclusive or with signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer. signal2 elements to be exclusive ored with signal1 elements
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsXor_32u_I(
        TypedPointer<Npp32u> pSrc,
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsXor_32u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsXor_32u_INative(
        TypedPointer<Npp32u> pSrc,
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    public static int nppsNot_8u(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsNot_8uNative(pSrc, pDst, nLength));
    }
    private static native int nppsNot_8uNative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short not signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNot_16u(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsNot_16uNative(pSrc, pDst, nLength));
    }
    private static native int nppsNot_16uNative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer not signal.
     * @param pSrc \ref source_signal_pointer.
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNot_32u(
        TypedPointer<Npp32u> pSrc,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsNot_32uNative(pSrc, pDst, nLength));
    }
    private static native int nppsNot_32uNative(
        TypedPointer<Npp32u> pSrc,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place not signal.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNot_8u_I(
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsNot_8u_INative(pSrcDst, nLength));
    }
    private static native int nppsNot_8u_INative(
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place not signal.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNot_16u_I(
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsNot_16u_INative(pSrcDst, nLength));
    }
    private static native int nppsNot_16u_INative(
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned signed integer in place not signal.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNot_32u_I(
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsNot_32u_INative(pSrcDst, nLength));
    }
    private static native int nppsNot_32u_INative(
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal left shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_8u(
        TypedPointer<Npp8u> pSrc,
        int nValue,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_8uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsLShiftC_8uNative(
        TypedPointer<Npp8u> pSrc,
        int nValue,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal left shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_16u(
        TypedPointer<Npp16u> pSrc,
        int nValue,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_16uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsLShiftC_16uNative(
        TypedPointer<Npp16u> pSrc,
        int nValue,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal left shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_16s(
        TypedPointer<Npp16s> pSrc,
        int nValue,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_16sNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsLShiftC_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nValue,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer signal left shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_32u(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_32uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsLShiftC_32uNative(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed integer signal left shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_32s(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_32sNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsLShiftC_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal left shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_8u_I(
        int nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_8u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsLShiftC_8u_INative(
        int nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place signal left shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_16u_I(
        int nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_16u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsLShiftC_16u_INative(
        int nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short in place signal left shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_16s_I(
        int nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_16s_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsLShiftC_16s_INative(
        int nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned signed integer in place signal left shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_32u_I(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_32u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsLShiftC_32u_INative(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed signed integer in place signal left shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to left shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsLShiftC_32s_I(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsLShiftC_32s_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsLShiftC_32s_INative(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char signal right shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_8u(
        TypedPointer<Npp8u> pSrc,
        int nValue,
        TypedPointer<Npp8u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_8uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsRShiftC_8uNative(
        TypedPointer<Npp8u> pSrc,
        int nValue,
        TypedPointer<Npp8u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short signal right shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_16u(
        TypedPointer<Npp16u> pSrc,
        int nValue,
        TypedPointer<Npp16u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_16uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsRShiftC_16uNative(
        TypedPointer<Npp16u> pSrc,
        int nValue,
        TypedPointer<Npp16u> pDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short signal right shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_16s(
        TypedPointer<Npp16s> pSrc,
        int nValue,
        TypedPointer<Npp16s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_16sNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsRShiftC_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nValue,
        TypedPointer<Npp16s> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned integer signal right shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_32u(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_32uNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsRShiftC_32uNative(
        TypedPointer<Npp32u> pSrc,
        int nValue,
        TypedPointer<Npp32u> pDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed integer signal right shift with constant.
     * @param pSrc \ref source_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param pDst \ref destination_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_32s(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_32sNative(pSrc, nValue, pDst, nLength));
    }
    private static native int nppsRShiftC_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nValue,
        TypedPointer<Npp32s> pDst,
        int nLength);


    /**
     * <pre>
     * 8-bit unsigned char in place signal right shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_8u_I(
        int nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_8u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsRShiftC_8u_INative(
        int nValue,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short in place signal right shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_16u_I(
        int nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_16u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsRShiftC_16u_INative(
        int nValue,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short in place signal right shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_16s_I(
        int nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_16s_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsRShiftC_16s_INative(
        int nValue,
        TypedPointer<Npp16s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit unsigned signed integer in place signal right shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_32u_I(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_32u_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsRShiftC_32u_INative(
        int nValue,
        TypedPointer<Npp32u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed signed integer in place signal right shift with constant.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nValue Constant value to be used to right shift each vector element
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsRShiftC_32s_I(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsRShiftC_32s_INative(nValue, pSrcDst, nLength));
    }
    private static native int nppsRShiftC_32s_INative(
        int nValue,
        TypedPointer<Npp32s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 8-bit in place min value for each pair of elements.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinEvery_8u_I(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMinEvery_8u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMinEvery_8u_INative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    public static int nppsMinEvery_16u_I(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMinEvery_16u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMinEvery_16u_INative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short integer in place min value for each pair of elements.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinEvery_16s_I(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMinEvery_16s_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMinEvery_16s_INative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed integer in place min value for each pair of elements.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinEvery_32s_I(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMinEvery_32s_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMinEvery_32s_INative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point in place min value for each pair of elements.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinEvery_32f_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMinEvery_32f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMinEvery_32f_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    public static int nppsMinEvery_64f_I(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMinEvery_64f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMinEvery_64f_INative(
        TypedPointer<Npp64f> pSrc,
        TypedPointer<Npp64f> pSrcDst,
        int nLength);


    public static int nppsMaxEvery_8u_I(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMaxEvery_8u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMaxEvery_8u_INative(
        TypedPointer<Npp8u> pSrc,
        TypedPointer<Npp8u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit unsigned short integer in place max value for each pair of elements.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxEvery_16u_I(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMaxEvery_16u_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMaxEvery_16u_INative(
        TypedPointer<Npp16u> pSrc,
        TypedPointer<Npp16u> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 16-bit signed short integer in place max value for each pair of elements.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxEvery_16s_I(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMaxEvery_16s_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMaxEvery_16s_INative(
        TypedPointer<Npp16s> pSrc,
        TypedPointer<Npp16s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit signed integer in place max value for each pair of elements.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxEvery_32s_I(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMaxEvery_32s_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMaxEvery_32s_INative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pSrcDst,
        int nLength);


    /**
     * <pre>
     * 32-bit floating point in place max value for each pair of elements.
     * @param pSrc \ref source_signal_pointer.
     * @param pSrcDst \ref in_place_signal_pointer.
     * @param nLength \ref length_specification.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxEvery_32f_I(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength)
    {
        return JNpp.checkResult(nppsMaxEvery_32f_INative(pSrc, pSrcDst, nLength));
    }
    private static native int nppsMaxEvery_32f_INative(
        TypedPointer<Npp32f> pSrc,
        TypedPointer<Npp32f> pSrcDst,
        int nLength);


    public static int nppsSumGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsSumGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsSum_32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumGetBufferSize_32fc(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsSumGetBufferSize_32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_32fcNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsSum_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsSumGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsSum_64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumGetBufferSize_64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsSumGetBufferSize_64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_64fcNative(
        int nLength,
        int[] hpBufferSize);


    public static int nppsSumGetBufferSize_16s_Sfs(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsSumGetBufferSize_16s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_16s_SfsNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsSum_16sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumGetBufferSize_16sc_Sfs(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsSumGetBufferSize_16sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_16sc_SfsNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsSum_16sc32sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumGetBufferSize_16sc32sc_Sfs(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsSumGetBufferSize_16sc32sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_16sc32sc_SfsNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsSum_32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumGetBufferSize_32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsSumGetBufferSize_32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsSum_16s32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsSumGetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsSumGetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsSumGetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float vector sum method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pSum,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_32fNative(pSrc, nLength, pSum, pDeviceBuffer));
    }
    private static native int nppsSum_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pSum,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit float complex vector sum method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_32fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_32fc(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pSum,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_32fcNative(pSrc, nLength, pSum, pDeviceBuffer));
    }
    private static native int nppsSum_32fcNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pSum,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit double vector sum method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pSum,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_64fNative(pSrc, nLength, pSum, pDeviceBuffer));
    }
    private static native int nppsSum_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pSum,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit double complex vector sum method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_64fc(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pSum,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_64fcNative(pSrc, nLength, pSum, pDeviceBuffer));
    }
    private static native int nppsSum_64fcNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pSum,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit short vector sum with integer scaling method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_16s_Sfs to determine the minium number of bytes required.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_16s_SfsNative(pSrc, nLength, pSum, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsSum_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector sum with integer scaling method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_32s_Sfs to determine the minium number of bytes required.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_32s_SfsNative(pSrc, nLength, pSum, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsSum_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit short complex vector sum with integer scaling method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_16sc_Sfs to determine the minium number of bytes required.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_16sc_SfsNative(pSrc, nLength, pSum, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsSum_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit short complex vector sum (32bit int complex) with integer scaling
     * method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_16sc32sc_Sfs to determine the minium number of bytes required.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_16sc32sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_16sc32sc_SfsNative(pSrc, nLength, pSum, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsSum_16sc32sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit integer vector sum (32bit) with integer scaling method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pSum Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsSumGetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsSum_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsSum_16s32s_SfsNative(pSrc, nLength, pSum, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsSum_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pSum,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMax_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMaxGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMax_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaxGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMax_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMaxGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMax_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMaxGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 16-bit integer vector max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMax Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMax_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMax_16sNative(pSrc, nLength, pMax, pDeviceBuffer));
    }
    private static native int nppsMax_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMax Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMax_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMax_32sNative(pSrc, nLength, pMax, pDeviceBuffer));
    }
    private static native int nppsMax_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit float vector max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMax Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMax_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMax_32fNative(pSrc, nLength, pMax, pDeviceBuffer));
    }
    private static native int nppsMax_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit float vector max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMax Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMax_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMax_64fNative(pSrc, nLength, pMax, pDeviceBuffer));
    }
    private static native int nppsMax_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMaxIndx_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxIndxGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMaxIndxGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxIndxGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMaxIndx_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxIndxGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMaxIndxGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxIndxGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMaxIndx_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxIndxGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaxIndxGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxIndxGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMaxIndx_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxIndxGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaxIndxGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxIndxGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit integer vector max index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMax Pointer to the output result.
     * @param pIndx Pointer to the index value of the first maximum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxIndxGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxIndx_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMax,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaxIndx_16sNative(pSrc, nLength, pMax, pIndx, pDeviceBuffer));
    }
    private static native int nppsMaxIndx_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMax,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector max index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMax Pointer to the output result.
     * @param pIndx Pointer to the index value of the first maximum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxIndxGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxIndx_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMax,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaxIndx_32sNative(pSrc, nLength, pMax, pIndx, pDeviceBuffer));
    }
    private static native int nppsMaxIndx_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMax,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit float vector max index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMax Pointer to the output result.
     * @param pIndx Pointer to the index value of the first maximum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxIndxGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxIndx_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMax,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaxIndx_32fNative(pSrc, nLength, pMax, pIndx, pDeviceBuffer));
    }
    private static native int nppsMaxIndx_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMax,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsMaxIndx_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMax,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaxIndx_64fNative(pSrc, nLength, pMax, pIndx, pDeviceBuffer));
    }
    private static native int nppsMaxIndx_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMax,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMaxAbs_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxAbsGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaxAbsGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxAbsGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMaxAbs_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxAbsGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMaxAbsGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxAbsGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 16-bit integer vector max absolute method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMaxAbs Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxAbsGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxAbs_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMaxAbs,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaxAbs_16sNative(pSrc, nLength, pMaxAbs, pDeviceBuffer));
    }
    private static native int nppsMaxAbs_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMaxAbs,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsMaxAbs_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMaxAbs,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaxAbs_32sNative(pSrc, nLength, pMaxAbs, pDeviceBuffer));
    }
    private static native int nppsMaxAbs_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMaxAbs,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMaxAbsIndx_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxAbsIndxGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMaxAbsIndxGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxAbsIndxGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMaxAbsIndx_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaxAbsIndxGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMaxAbsIndxGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaxAbsIndxGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 16-bit integer vector max absolute index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMaxAbs Pointer to the output result.
     * @param pIndx Pointer to the index value of the first maximum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxAbsIndxGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxAbsIndx_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMaxAbs,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaxAbsIndx_16sNative(pSrc, nLength, pMaxAbs, pIndx, pDeviceBuffer));
    }
    private static native int nppsMaxAbsIndx_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMaxAbs,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector max absolute index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMaxAbs Pointer to the output result.
     * @param pIndx Pointer to the index value of the first maximum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaxAbsIndxGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaxAbsIndx_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMaxAbs,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaxAbsIndx_32sNative(pSrc, nLength, pMaxAbs, pIndx, pDeviceBuffer));
    }
    private static native int nppsMaxAbsIndx_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMaxAbs,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /** @} signal_max */
    /**
     * <pre>
     * @defgroup signal_min Minimum
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMin_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMin_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMinGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    public static int nppsMinGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMinGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMinGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMin_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMinGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit integer vector min method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMin_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMin,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMin_16sNative(pSrc, nLength, pMin, pDeviceBuffer));
    }
    private static native int nppsMin_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMin,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsMin_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMin,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMin_32sNative(pSrc, nLength, pMin, pDeviceBuffer));
    }
    private static native int nppsMin_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMin,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector min method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMin_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMin,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMin_32fNative(pSrc, nLength, pMin, pDeviceBuffer));
    }
    private static native int nppsMin_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMin,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit integer vector min method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMin_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMin,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMin_64fNative(pSrc, nLength, pMin, pDeviceBuffer));
    }
    private static native int nppsMin_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMin,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMinIndx_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinIndxGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMinIndxGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinIndxGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMinIndx_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinIndxGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinIndxGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinIndxGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMinIndx_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinIndxGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinIndxGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMinIndxGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMinIndx_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinIndxGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinIndxGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMinIndxGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    public static int nppsMinIndx_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMin,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinIndx_16sNative(pSrc, nLength, pMin, pIndx, pDeviceBuffer));
    }
    private static native int nppsMinIndx_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMin,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector min index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the output result.
     * @param pIndx Pointer to the index value of the first minimum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinIndxGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinIndx_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMin,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinIndx_32sNative(pSrc, nLength, pMin, pIndx, pDeviceBuffer));
    }
    private static native int nppsMinIndx_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMin,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit float vector min index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the output result.
     * @param pIndx Pointer to the index value of the first minimum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinIndxGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinIndx_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMin,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinIndx_32fNative(pSrc, nLength, pMin, pIndx, pDeviceBuffer));
    }
    private static native int nppsMinIndx_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMin,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit float vector min index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the output result.
     * @param pIndx Pointer to the index value of the first minimum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinIndxGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinIndx_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMin,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinIndx_64fNative(pSrc, nLength, pMin, pIndx, pDeviceBuffer));
    }
    private static native int nppsMinIndx_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMin,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMinAbs_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinAbsGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMinAbsGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinAbsGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMinAbs_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinAbsGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMinAbsGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinAbsGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 16-bit integer vector min absolute method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMinAbs Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinAbsGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinAbs_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMinAbs,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinAbs_16sNative(pSrc, nLength, pMinAbs, pDeviceBuffer));
    }
    private static native int nppsMinAbs_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMinAbs,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector min absolute method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMinAbs Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinAbsGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinAbs_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMinAbs,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinAbs_32sNative(pSrc, nLength, pMinAbs, pDeviceBuffer));
    }
    private static native int nppsMinAbs_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMinAbs,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMinAbsIndx_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinAbsIndxGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMinAbsIndxGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinAbsIndxGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMinAbsIndx_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinAbsIndxGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinAbsIndxGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinAbsIndxGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit integer vector min absolute index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMinAbs Pointer to the output result.
     * @param pIndx Pointer to the index value of the first minimum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinAbsIndxGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinAbsIndx_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMinAbs,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinAbsIndx_16sNative(pSrc, nLength, pMinAbs, pIndx, pDeviceBuffer));
    }
    private static native int nppsMinAbsIndx_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMinAbs,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector min absolute index method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMinAbs Pointer to the output result.
     * @param pIndx Pointer to the index value of the first minimum element.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinAbsIndxGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinAbsIndx_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMinAbs,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinAbsIndx_32sNative(pSrc, nLength, pMinAbs, pIndx, pDeviceBuffer));
    }
    private static native int nppsMinAbsIndx_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMinAbs,
        int[] pIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMean_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMean_32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanGetBufferSize_32fc(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanGetBufferSize_32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanGetBufferSize_32fcNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMean_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMean_64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanGetBufferSize_64fc(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanGetBufferSize_64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanGetBufferSize_64fcNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMean_16s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanGetBufferSize_16s_Sfs(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanGetBufferSize_16s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanGetBufferSize_16s_SfsNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMean_32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanGetBufferSize_32s_Sfs(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanGetBufferSize_32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanGetBufferSize_32s_SfsNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMean_16sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanGetBufferSize_16sc_Sfs(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanGetBufferSize_16sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanGetBufferSize_16sc_SfsNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 32-bit float vector mean method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMean_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMean,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMean_32fNative(pSrc, nLength, pMean, pDeviceBuffer));
    }
    private static native int nppsMean_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMean,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit float complex vector mean method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanGetBufferSize_32fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMean_32fc(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMean,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMean_32fcNative(pSrc, nLength, pMean, pDeviceBuffer));
    }
    private static native int nppsMean_32fcNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMean,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit double vector mean method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMean_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMean,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMean_64fNative(pSrc, nLength, pMean, pDeviceBuffer));
    }
    private static native int nppsMean_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMean,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit double complex vector mean method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanGetBufferSize_64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMean_64fc(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMean,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMean_64fcNative(pSrc, nLength, pMean, pDeviceBuffer));
    }
    private static native int nppsMean_64fcNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMean,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit short vector mean with integer scaling method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanGetBufferSize_16s_Sfs to determine the minium number of bytes required.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMean_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMean,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMean_16s_SfsNative(pSrc, nLength, pMean, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsMean_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMean,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit integer vector mean with integer scaling method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanGetBufferSize_32s_Sfs to determine the minium number of bytes required.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMean_32s_Sfs(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMean,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMean_32s_SfsNative(pSrc, nLength, pMean, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsMean_32s_SfsNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMean,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit short complex vector mean with integer scaling method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanGetBufferSize_16sc_Sfs to determine the minium number of bytes required.
     * @param nScaleFactor \ref integer_result_scaling.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMean_16sc_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMean,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMean_16sc_SfsNative(pSrc, nLength, pMean, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsMean_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMean,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsStdDev_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsStdDevGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsStdDevGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsStdDevGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsStdDev_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsStdDevGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsStdDevGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsStdDevGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    public static int nppsStdDevGetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsStdDevGetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsStdDevGetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsStdDev_16s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsStdDevGetBufferSize_16s_Sfs(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsStdDevGetBufferSize_16s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsStdDevGetBufferSize_16s_SfsNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * 32-bit float vector standard deviation method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pStdDev Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsStdDevGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsStdDev_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pStdDev,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsStdDev_32fNative(pSrc, nLength, pStdDev, pDeviceBuffer));
    }
    private static native int nppsStdDev_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pStdDev,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit float vector standard deviation method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pStdDev Pointer to the output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsStdDevGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsStdDev_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pStdDev,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsStdDev_64fNative(pSrc, nLength, pStdDev, pDeviceBuffer));
    }
    private static native int nppsStdDev_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pStdDev,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit float vector standard deviation method (return value is 32-bit)
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pStdDev Pointer to the output result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsStdDevGetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsStdDev_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pStdDev,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsStdDev_16s32s_SfsNative(pSrc, nLength, pStdDev, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsStdDev_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pStdDev,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit float vector standard deviation method (return value is also 16-bit)
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pStdDev Pointer to the output result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsStdDevGetBufferSize_16s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsStdDev_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pStdDev,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsStdDev_16s_SfsNative(pSrc, nLength, pStdDev, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsStdDev_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pStdDev,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMeanStdDev_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanStdDevGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanStdDevGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanStdDevGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMeanStdDev_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanStdDevGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanStdDevGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanStdDevGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    public static int nppsMeanStdDevGetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)/** host pointer */
    {
        return JNpp.checkResult(nppsMeanStdDevGetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanStdDevGetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);/** host pointer */


    /**
     * <pre>
     * Device scratch buffer size (in bytes) for nppsMeanStdDev_16s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size. Important: hpBufferSize is a
     *        <em>host pointer.</em> \ref general_scratch_buffer.
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMeanStdDevGetBufferSize_16s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMeanStdDevGetBufferSize_16s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsMeanStdDevGetBufferSize_16s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float vector mean and standard deviation method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output mean value.
     * @param pStdDev Pointer to the output standard deviation value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanStdDevGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMeanStdDev_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMean,
        TypedPointer<Npp32f> pStdDev,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMeanStdDev_32fNative(pSrc, nLength, pMean, pStdDev, pDeviceBuffer));
    }
    private static native int nppsMeanStdDev_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMean,
        TypedPointer<Npp32f> pStdDev,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit float vector mean and standard deviation method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output mean value.
     * @param pStdDev Pointer to the output standard deviation value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanStdDevGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMeanStdDev_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMean,
        TypedPointer<Npp64f> pStdDev,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMeanStdDev_64fNative(pSrc, nLength, pMean, pStdDev, pDeviceBuffer));
    }
    private static native int nppsMeanStdDev_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMean,
        TypedPointer<Npp64f> pStdDev,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit float vector mean and standard deviation method (return values are 32-bit)
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output mean value.
     * @param pStdDev Pointer to the output standard deviation value.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanStdDevGetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMeanStdDev_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMean,
        TypedPointer<Npp32s> pStdDev,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMeanStdDev_16s32s_SfsNative(pSrc, nLength, pMean, pStdDev, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsMeanStdDev_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMean,
        TypedPointer<Npp32s> pStdDev,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit float vector mean and standard deviation method (return values are also 16-bit)
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMean Pointer to the output mean value.
     * @param pStdDev Pointer to the output standard deviation value.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMeanStdDevGetBufferSize_16s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMeanStdDev_16s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMean,
        TypedPointer<Npp16s> pStdDev,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMeanStdDev_16s_SfsNative(pSrc, nLength, pMean, pStdDev, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsMeanStdDev_16s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMean,
        TypedPointer<Npp16s> pStdDev,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /** @} signal_mean_and_standard_deviation */
    /**
     * <pre>
     * @defgroup signal_min_max Minimum_Maximum
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMax_8u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxGetBufferSize_8u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxGetBufferSize_8uNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxGetBufferSize_8uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMax_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMax_16u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxGetBufferSize_16u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxGetBufferSize_16uNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxGetBufferSize_16uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMax_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMax_32u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxGetBufferSize_32u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxGetBufferSize_32uNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxGetBufferSize_32uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMax_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMax_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 8-bit char vector min and max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMax Pointer to the max output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxGetBufferSize_8u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMax_8u(
        TypedPointer<Npp8u> pSrc,
        int nLength,
        TypedPointer<Npp8u> pMin,
        TypedPointer<Npp8u> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMax_8uNative(pSrc, nLength, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppsMinMax_8uNative(
        TypedPointer<Npp8u> pSrc,
        int nLength,
        TypedPointer<Npp8u> pMin,
        TypedPointer<Npp8u> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit signed short vector min and max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMax Pointer to the max output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMax_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMin,
        TypedPointer<Npp16s> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMax_16sNative(pSrc, nLength, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppsMinMax_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMin,
        TypedPointer<Npp16s> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short vector min and max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMax Pointer to the max output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxGetBufferSize_16u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMax_16u(
        TypedPointer<Npp16u> pSrc,
        int nLength,
        TypedPointer<Npp16u> pMin,
        TypedPointer<Npp16u> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMax_16uNative(pSrc, nLength, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppsMinMax_16uNative(
        TypedPointer<Npp16u> pSrc,
        int nLength,
        TypedPointer<Npp16u> pMin,
        TypedPointer<Npp16u> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned int vector min and max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMax Pointer to the max output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxGetBufferSize_32u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMax_32u(
        TypedPointer<Npp32u> pSrc,
        int nLength,
        TypedPointer<Npp32u> pMin,
        TypedPointer<Npp32u> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMax_32uNative(pSrc, nLength, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppsMinMax_32uNative(
        TypedPointer<Npp32u> pSrc,
        int nLength,
        TypedPointer<Npp32u> pMin,
        TypedPointer<Npp32u> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit signed int vector min and max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMax Pointer to the max output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMax_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMin,
        TypedPointer<Npp32s> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMax_32sNative(pSrc, nLength, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppsMinMax_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMin,
        TypedPointer<Npp32s> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit float vector min and max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMax Pointer to the max output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMax_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMin,
        TypedPointer<Npp32f> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMax_32fNative(pSrc, nLength, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppsMinMax_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMin,
        TypedPointer<Npp32f> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit double vector min and max method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMax Pointer to the max output result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMax_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMin,
        TypedPointer<Npp64f> pMax,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMax_64fNative(pSrc, nLength, pMin, pMax, pDeviceBuffer));
    }
    private static native int nppsMinMax_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMin,
        TypedPointer<Npp64f> pMax,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMaxIndx_8u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxIndxGetBufferSize_8u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxIndxGetBufferSize_8uNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxIndxGetBufferSize_8uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMaxIndx_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxIndxGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxIndxGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxIndxGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMaxIndx_16u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxIndxGetBufferSize_16u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxIndxGetBufferSize_16uNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxIndxGetBufferSize_16uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMaxIndx_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxIndxGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxIndxGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxIndxGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMaxIndx_32u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxIndxGetBufferSize_32u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxIndxGetBufferSize_32uNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxIndxGetBufferSize_32uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMaxIndx_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxIndxGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxIndxGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxIndxGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMinMaxIndx_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMinMaxIndxGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMinMaxIndxGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMinMaxIndxGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 8-bit char vector min and max with indices method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMinIndx Pointer to the index of the first min value.
     * @param pMax Pointer to the max output result.
     * @param pMaxIndx Pointer to the index of the first max value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxIndxGetBufferSize_8u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMaxIndx_8u(
        TypedPointer<Npp8u> pSrc,
        int nLength,
        TypedPointer<Npp8u> pMin,
        int[] pMinIndx,
        TypedPointer<Npp8u> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMaxIndx_8uNative(pSrc, nLength, pMin, pMinIndx, pMax, pMaxIndx, pDeviceBuffer));
    }
    private static native int nppsMinMaxIndx_8uNative(
        TypedPointer<Npp8u> pSrc,
        int nLength,
        TypedPointer<Npp8u> pMin,
        int[] pMinIndx,
        TypedPointer<Npp8u> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit signed short vector min and max with indices method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMinIndx Pointer to the index of the first min value.
     * @param pMax Pointer to the max output result.
     * @param pMaxIndx Pointer to the index of the first max value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxIndxGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMaxIndx_16s(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMin,
        int[] pMinIndx,
        TypedPointer<Npp16s> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMaxIndx_16sNative(pSrc, nLength, pMin, pMinIndx, pMax, pMaxIndx, pDeviceBuffer));
    }
    private static native int nppsMinMaxIndx_16sNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp16s> pMin,
        int[] pMinIndx,
        TypedPointer<Npp16s> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short vector min and max with indices method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMinIndx Pointer to the index of the first min value.
     * @param pMax Pointer to the max output result.
     * @param pMaxIndx Pointer to the index of the first max value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxIndxGetBufferSize_16u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMaxIndx_16u(
        TypedPointer<Npp16u> pSrc,
        int nLength,
        TypedPointer<Npp16u> pMin,
        int[] pMinIndx,
        TypedPointer<Npp16u> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMaxIndx_16uNative(pSrc, nLength, pMin, pMinIndx, pMax, pMaxIndx, pDeviceBuffer));
    }
    private static native int nppsMinMaxIndx_16uNative(
        TypedPointer<Npp16u> pSrc,
        int nLength,
        TypedPointer<Npp16u> pMin,
        int[] pMinIndx,
        TypedPointer<Npp16u> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit signed short vector min and max with indices method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMinIndx Pointer to the index of the first min value.
     * @param pMax Pointer to the max output result.
     * @param pMaxIndx Pointer to the index of the first max value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxIndxGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMaxIndx_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMin,
        int[] pMinIndx,
        TypedPointer<Npp32s> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMaxIndx_32sNative(pSrc, nLength, pMin, pMinIndx, pMax, pMaxIndx, pDeviceBuffer));
    }
    private static native int nppsMinMaxIndx_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pMin,
        int[] pMinIndx,
        TypedPointer<Npp32s> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short vector min and max with indices method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMinIndx Pointer to the index of the first min value.
     * @param pMax Pointer to the max output result.
     * @param pMaxIndx Pointer to the index of the first max value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxIndxGetBufferSize_32u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMaxIndx_32u(
        TypedPointer<Npp32u> pSrc,
        int nLength,
        TypedPointer<Npp32u> pMin,
        int[] pMinIndx,
        TypedPointer<Npp32u> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMaxIndx_32uNative(pSrc, nLength, pMin, pMinIndx, pMax, pMaxIndx, pDeviceBuffer));
    }
    private static native int nppsMinMaxIndx_32uNative(
        TypedPointer<Npp32u> pSrc,
        int nLength,
        TypedPointer<Npp32u> pMin,
        int[] pMinIndx,
        TypedPointer<Npp32u> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit float vector min and max with indices method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMinIndx Pointer to the index of the first min value.
     * @param pMax Pointer to the max output result.
     * @param pMaxIndx Pointer to the index of the first max value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxIndxGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMaxIndx_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMin,
        int[] pMinIndx,
        TypedPointer<Npp32f> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMaxIndx_32fNative(pSrc, nLength, pMin, pMinIndx, pMax, pMaxIndx, pDeviceBuffer));
    }
    private static native int nppsMinMaxIndx_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pMin,
        int[] pMinIndx,
        TypedPointer<Npp32f> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit float vector min and max with indices method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pMin Pointer to the min output result.
     * @param pMinIndx Pointer to the index of the first min value.
     * @param pMax Pointer to the max output result.
     * @param pMaxIndx Pointer to the index of the first max value.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMinMaxIndxGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMinMaxIndx_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMin,
        int[] pMinIndx,
        TypedPointer<Npp64f> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMinMaxIndx_64fNative(pSrc, nLength, pMin, pMinIndx, pMax, pMaxIndx, pDeviceBuffer));
    }
    private static native int nppsMinMaxIndx_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pMin,
        int[] pMinIndx,
        TypedPointer<Npp64f> pMax,
        int[] pMaxIndx,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_Inf_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormInfGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormInfGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormInfGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float vector C norm method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormInfGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_Inf_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_Inf_32fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_Inf_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_Inf_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormInfGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormInfGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormInfGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float vector C norm method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormInfGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_Inf_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_Inf_64fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_Inf_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsNormInfGetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormInfGetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormInfGetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer vector C norm method, return value is 32-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormInfGetBufferSize_16s32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_Inf_16s32f(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_Inf_16s32fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_Inf_16s32fNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_Inf_32fc32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormInfGetBufferSize_32fc32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormInfGetBufferSize_32fc32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormInfGetBufferSize_32fc32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float complex vector C norm method, return value is 32-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormInfGetBufferSize_32fc32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_Inf_32fc32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_Inf_32fc32fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_Inf_32fc32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_Inf_64fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormInfGetBufferSize_64fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormInfGetBufferSize_64fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormInfGetBufferSize_64fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float complex vector C norm method, return value is 64-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormInfGetBufferSize_64fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_Inf_64fc64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_Inf_64fc64fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_Inf_64fc64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsNormInfGetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormInfGetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormInfGetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer vector C norm method, return value is 32-bit signed integer.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormInfGetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_Inf_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_Inf_16s32s_SfsNative(pSrc, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNorm_Inf_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L1_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL1GetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL1GetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL1GetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float vector L1 norm method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL1GetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L1_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L1_32fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L1_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L1_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL1GetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL1GetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL1GetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float vector L1 norm method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL1GetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L1_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L1_64fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L1_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L1_16s32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL1GetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL1GetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL1GetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer vector L1 norm method, return value is 32-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the L1 norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL1GetBufferSize_16s32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L1_16s32f(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L1_16s32fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L1_16s32fNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L1_32fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL1GetBufferSize_32fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL1GetBufferSize_32fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL1GetBufferSize_32fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float complex vector L1 norm method, return value is 64-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL1GetBufferSize_32fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L1_32fc64f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L1_32fc64fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L1_32fc64fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L1_64fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL1GetBufferSize_64fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL1GetBufferSize_64fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL1GetBufferSize_64fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float complex vector L1 norm method, return value is 64-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL1GetBufferSize_64fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L1_64fc64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L1_64fc64fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L1_64fc64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L1_16s32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL1GetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL1GetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL1GetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer vector L1 norm method, return value is 32-bit signed integer.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL1GetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L1_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L1_16s32s_SfsNative(pSrc, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNorm_L1_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L1_16s64s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL1GetBufferSize_16s64s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL1GetBufferSize_16s64s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL1GetBufferSize_16s64s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer vector L1 norm method, return value is 64-bit signed integer.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL1GetBufferSize_16s64s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L1_16s64s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp64s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L1_16s64s_SfsNative(pSrc, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNorm_L1_16s64s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp64s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L2_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL2GetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL2GetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL2GetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float vector L2 norm method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL2GetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L2_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L2_32fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L2_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L2_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL2GetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL2GetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL2GetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float vector L2 norm method
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL2GetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L2_64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L2_64fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L2_64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsNormL2GetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL2GetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL2GetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer vector L2 norm method, return value is 32-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL2GetBufferSize_16s32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L2_16s32f(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L2_16s32fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L2_16s32fNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L2_32fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL2GetBufferSize_32fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL2GetBufferSize_32fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL2GetBufferSize_32fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float complex vector L2 norm method, return value is 64-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL2GetBufferSize_32fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L2_32fc64f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L2_32fc64fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L2_32fc64fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L2_64fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL2GetBufferSize_64fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL2GetBufferSize_64fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL2GetBufferSize_64fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float complex vector L2 norm method, return value is 64-bit float.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL2GetBufferSize_64fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L2_64fc64f(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L2_64fc64fNative(pSrc, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNorm_L2_64fc64fNative(
        TypedPointer<Npp64f> pSrc,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L2_16s32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL2GetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL2GetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL2GetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer vector L2 norm method, return value is 32-bit signed integer.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL2GetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L2_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L2_16s32s_SfsNative(pSrc, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNorm_L2_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNorm_L2Sqr_16s64s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormL2SqrGetBufferSize_16s64s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormL2SqrGetBufferSize_16s64s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormL2SqrGetBufferSize_16s64s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer vector L2 Square norm method, return value is 64-bit signed integer.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormL2SqrGetBufferSize_16s64s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNorm_L2Sqr_16s64s_Sfs(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp64s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNorm_L2Sqr_16s64s_SfsNative(pSrc, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNorm_L2Sqr_16s64s_SfsNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp64s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /** @} signal_L2_norm */
    /**
     * <pre>
     * @defgroup signal_infinity_norm_diff Infinity Norm Diff
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_Inf_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffInfGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffInfGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffInfGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float C norm method on two vectors' difference
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffInfGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_Inf_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_Inf_32fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_Inf_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_Inf_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffInfGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffInfGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffInfGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float C norm method on two vectors' difference
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffInfGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_Inf_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_Inf_64fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_Inf_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_Inf_16s32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffInfGetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffInfGetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffInfGetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer C norm method on two vectors' difference, return value is 32-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffInfGetBufferSize_16s32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_Inf_16s32f(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_Inf_16s32fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_Inf_16s32fNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_Inf_32fc32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffInfGetBufferSize_32fc32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffInfGetBufferSize_32fc32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffInfGetBufferSize_32fc32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float complex C norm method on two vectors' difference, return value is 32-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffInfGetBufferSize_32fc32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_Inf_32fc32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_Inf_32fc32fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_Inf_32fc32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_Inf_64fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffInfGetBufferSize_64fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffInfGetBufferSize_64fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffInfGetBufferSize_64fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float complex C norm method on two vectors' difference, return value is 64-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffInfGetBufferSize_64fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_Inf_64fc64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_Inf_64fc64fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_Inf_64fc64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_Inf_16s32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffInfGetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffInfGetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffInfGetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer C norm method on two vectors' difference, return value is 32-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffInfGetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_Inf_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_Inf_16s32s_SfsNative(pSrc1, pSrc2, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNormDiff_Inf_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L1_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL1GetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL1GetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL1GetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float L1 norm method on two vectors' difference
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL1GetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L1_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L1_32fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L1_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L1_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL1GetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL1GetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL1GetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float L1 norm method on two vectors' difference
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL1GetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L1_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L1_64fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L1_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L1_16s32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL1GetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL1GetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL1GetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer L1 norm method on two vectors' difference, return value is 32-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the L1 norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL1GetBufferSize_16s32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L1_16s32f(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L1_16s32fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L1_16s32fNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L1_32fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL1GetBufferSize_32fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL1GetBufferSize_32fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL1GetBufferSize_32fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float complex L1 norm method on two vectors' difference, return value is 64-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL1GetBufferSize_32fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L1_32fc64f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L1_32fc64fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L1_32fc64fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L1_64fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL1GetBufferSize_64fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL1GetBufferSize_64fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL1GetBufferSize_64fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float complex L1 norm method on two vectors' difference, return value is 64-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL1GetBufferSize_64fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L1_64fc64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L1_64fc64fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L1_64fc64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L1_16s32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL1GetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL1GetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL1GetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer L1 norm method on two vectors' difference, return value is 32-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer..
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL1GetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L1_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L1_16s32s_SfsNative(pSrc1, pSrc2, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L1_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L1_16s64s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL1GetBufferSize_16s64s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL1GetBufferSize_16s64s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL1GetBufferSize_16s64s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer L1 norm method on two vectors' difference, return value is 64-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL1GetBufferSize_16s64s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L1_16s64s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L1_16s64s_SfsNative(pSrc1, pSrc2, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L1_16s64s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /** @} signal_L1_norm_diff */
    /**
     * <pre>
     * @defgroup signal_L2_norm_diff L2 Norm Diff
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L2_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL2GetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL2GetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL2GetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float L2 norm method on two vectors' difference
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL2GetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L2_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L2_32fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L2_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L2_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL2GetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL2GetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL2GetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float L2 norm method on two vectors' difference
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL2GetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L2_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L2_64fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L2_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L2_16s32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL2GetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL2GetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL2GetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer L2 norm method on two vectors' difference, return value is 32-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL2GetBufferSize_16s32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L2_16s32f(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L2_16s32fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L2_16s32fNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsNormDiffL2GetBufferSize_32fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL2GetBufferSize_32fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL2GetBufferSize_32fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float complex L2 norm method on two vectors' difference, return value is 64-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL2GetBufferSize_32fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L2_32fc64f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L2_32fc64fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L2_32fc64fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L2_64fc64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL2GetBufferSize_64fc64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL2GetBufferSize_64fc64fNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL2GetBufferSize_64fc64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float complex L2 norm method on two vectors' difference, return value is 64-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL2GetBufferSize_64fc64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L2_64fc64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L2_64fc64fNative(pSrc1, pSrc2, nLength, pNorm, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L2_64fc64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pNorm,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L2_16s32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL2GetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL2GetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL2GetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer L2 norm method on two vectors' difference, return value is 32-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL2GetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L2_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L2_16s32s_SfsNative(pSrc1, pSrc2, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L2_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsNormDiff_L2Sqr_16s64s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsNormDiffL2SqrGetBufferSize_16s64s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsNormDiffL2SqrGetBufferSize_16s64s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsNormDiffL2SqrGetBufferSize_16s64s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer L2 Square norm method on two vectors' difference, return value is 64-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pNorm Pointer to the norm result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsNormDiffL2SqrGetBufferSize_16s64s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsNormDiff_L2Sqr_16s64s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsNormDiff_L2Sqr_16s64s_SfsNative(pSrc1, pSrc2, nLength, pNorm, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsNormDiff_L2Sqr_16s64s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pNorm,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /** @} signal_l2_norm_diff */
    /**
     * <pre>
     * @defgroup signal_dot_product Dot Product
     *
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float dot product method, return value is 32-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32fNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float complex dot product method, return value is 32-bit float complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_32fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32fcNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32f32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32f32fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32f32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32f32fcNative(
        int nLength,
        int[] hpBufferSize);


    public static int nppsDotProd_32f32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32f32fcNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_32f32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32f64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32f64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32f64fNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32f64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float dot product method, return value is 64-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_32f64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_32f64f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32f64fNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_32f64fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32fc64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32fc64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32fc64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32fc64fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float complex dot product method, return value is 64-bit float complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_32fc64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_32fc64fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32fc64fcNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_32fc64fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32f32fc64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32f32fc64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32f32fc64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32f32fc64fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit float and 32-bit float complex dot product method, return value is 64-bit float complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_32f32fc64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_32f32fc64fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32f32fc64fcNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_32f32fc64fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float dot product method, return value is 64-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_64fNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_64fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float complex dot product method, return value is 64-bit float complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_64fcNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_64f64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_64f64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_64f64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_64f64fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 64-bit float and 64-bit float complex dot product method, return value is 64-bit float complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_64f64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_64f64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_64f64fcNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_64f64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s64s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s64s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s64sNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s64sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer dot product method, return value is 64-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s64s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s64s(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s64sNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s64sNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16sc64sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16sc64sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16sc64scNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16sc64scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer complex dot product method, return value is 64-bit signed integer complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16sc64sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16sc64sc(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16sc64scNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_16sc64scNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s16sc64sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s16sc64sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s16sc64scNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s16sc64scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer and 16-bit signed short integer short dot product method, return value is 64-bit signed integer complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s16sc64sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s16sc64sc(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s16sc64scNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s16sc64scNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64s> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer dot product method, return value is 32-bit float.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s32f(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s32fNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s32fNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16sc32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16sc32fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16sc32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16sc32fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer complex dot product method, return value is 32-bit float complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16sc32fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16sc32fc(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16sc32fcNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_16sc32fcNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s16sc32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s16sc32fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s16sc32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s16sc32fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer and 16-bit signed short integer complex dot product method, return value is 32-bit float complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s16sc32fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s16sc32fc(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s16sc32fcNative(pSrc1, pSrc2, nLength, pDp, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s16sc32fcNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32f> pDp,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer dot product method, return value is 16-bit signed short integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp16s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp16s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16sc_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16sc_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer complex dot product method, return value is 16-bit signed short integer complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16sc_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16sc_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp16s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16sc_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_16sc_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp16s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit signed integer dot product method, return value is 32-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_32s_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32s_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_32s_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32sc_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32sc_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit signed integer complex dot product method, return value is 32-bit signed integer complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_32sc_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_32sc_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32sc_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_32sc_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer dot product method, return value is 32-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s32s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s32s_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s32s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s16sc32sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s16sc32sc_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s16sc32sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s16sc32sc_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer and 16-bit signed short integer complex dot product method, return value is 32-bit signed integer complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s16sc32sc_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s16sc32sc_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s16sc32sc_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s16sc32sc_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s32s32s_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s32s32s_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s32s32s_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s32s32s_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer and 32-bit signed integer dot product method, return value is 32-bit signed integer.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s32s32s_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s32s32s_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s32s32s_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s32s32s_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16s16sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16s16sc_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16s16sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16s16sc_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer and 16-bit signed short integer complex dot product method, return value is 16-bit signed short integer complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16s16sc_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16s16sc_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp16s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16s16sc_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_16s16sc_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp16s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_16sc32sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_16sc32sc_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_16sc32sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_16sc32sc_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer complex dot product method, return value is 32-bit signed integer complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_16sc32sc_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_16sc32sc_Sfs(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_16sc32sc_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_16sc32sc_SfsNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsDotProd_32s32sc_Sfs.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsDotProdGetBufferSize_32s32sc_Sfs(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsDotProdGetBufferSize_32s32sc_SfsNative(nLength, hpBufferSize));
    }
    private static native int nppsDotProdGetBufferSize_32s32sc_SfsNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit signed short integer and 32-bit signed short integer complex dot product method, return value is 32-bit signed integer complex.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDp Pointer to the dot product result.
     * @param nScaleFactor \ref integer_result_scaling.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsDotProdGetBufferSize_32s32sc_Sfs to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsDotProd_32s32sc_Sfs(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsDotProd_32s32sc_SfsNative(pSrc1, pSrc2, nLength, pDp, nScaleFactor, pDeviceBuffer));
    }
    private static native int nppsDotProd_32s32sc_SfsNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp32s> pDp,
        int nScaleFactor,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsCountInRange_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsCountInRangeGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsCountInRangeGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsCountInRangeGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Computes the number of elements whose values fall into the specified range on a 32-bit signed integer array.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pCounts Pointer to the number of elements.
     * @param nLowerBound Lower bound of the specified range.
     * @param nUpperBound Upper bound of the specified range.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsCountInRangeGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsCountInRange_32s(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        int[] pCounts,
        int nLowerBound,
        int nUpperBound,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsCountInRange_32sNative(pSrc, nLength, pCounts, nLowerBound, nUpperBound, pDeviceBuffer));
    }
    private static native int nppsCountInRange_32sNative(
        TypedPointer<Npp32s> pSrc,
        int nLength,
        int[] pCounts,
        int nLowerBound,
        int nUpperBound,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsZeroCrossing_16s32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsZeroCrossingGetBufferSize_16s32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsZeroCrossingGetBufferSize_16s32fNative(nLength, hpBufferSize));
    }
    private static native int nppsZeroCrossingGetBufferSize_16s32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 16-bit signed short integer zero crossing method, return value is 32-bit floating point.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pValZC Pointer to the output result.
     * @param tZCType Type of the zero crossing measure: nppZCR, nppZCXor or nppZCC.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsZeroCrossingGetBufferSize_16s32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZeroCrossing_16s32f(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pValZC,
        int tZCType,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsZeroCrossing_16s32fNative(pSrc, nLength, pValZC, tZCType, pDeviceBuffer));
    }
    private static native int nppsZeroCrossing_16s32fNative(
        TypedPointer<Npp16s> pSrc,
        int nLength,
        TypedPointer<Npp32f> pValZC,
        int tZCType,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsZeroCrossing_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsZeroCrossingGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsZeroCrossingGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsZeroCrossingGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 32-bit floating-point zero crossing method, return value is 32-bit floating point.
     * @param pSrc \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pValZC Pointer to the output result.
     * @param tZCType Type of the zero crossing measure: nppZCR, nppZCXor or nppZCC.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsZeroCrossingGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsZeroCrossing_32f(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pValZC,
        int tZCType,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsZeroCrossing_32fNative(pSrc, nLength, pValZC, tZCType, pDeviceBuffer));
    }
    private static native int nppsZeroCrossing_32fNative(
        TypedPointer<Npp32f> pSrc,
        int nLength,
        TypedPointer<Npp32f> pValZC,
        int tZCType,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 8-bit unsigned char maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_8u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_8u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_8uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_8uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 8-bit signed char maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_8s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_8s(
        TypedPointer<Npp8s> pSrc1,
        TypedPointer<Npp8s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_8sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_8sNative(
        TypedPointer<Npp8s> pSrc1,
        TypedPointer<Npp8s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short integer maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_16u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_16u(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_16uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_16uNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit signed short integer maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_16s(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_16sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_16sNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short complex integer maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_16sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_16sc(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_16scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_16scNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short integer maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_32u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_32u(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_32uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_32uNative(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit signed short integer maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_32s(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_32sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_32sNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short complex integer maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_32sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_32sc(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_32scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_32scNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit signed short integer maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_64s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_64s(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_64sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_64sNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit unsigned short complex integer maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_64sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_64sc(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_64scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_64scNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit floating point maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_32fNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit floating point complex maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_32fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_32fcNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit floating point maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_64fNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit floating point complex maximum method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumErrorGetBufferSize_64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumError_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumError_64fcNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumError_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_8u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_8u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_8uNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_8uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_8s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_8s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_8sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_8sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_16u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_16u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_16uNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_16uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_16sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_16sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_16scNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_16scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_32u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_32u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_32uNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_32uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_32sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_32sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_32scNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_32scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_64s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_64s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_64sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_64sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_64sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_64sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_64scNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_64scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_32fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_32fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumError_64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumErrorGetBufferSize_64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumErrorGetBufferSize_64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumErrorGetBufferSize_64fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 8-bit unsigned char Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_8u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_8u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_8uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_8uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsAverageError_8s(
        TypedPointer<Npp8s> pSrc1,
        TypedPointer<Npp8s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_8sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_8sNative(
        TypedPointer<Npp8s> pSrc1,
        TypedPointer<Npp8s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short integer Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_16u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_16u(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_16uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_16uNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit signed short integer Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_16s(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_16sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_16sNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short complex integer Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_16sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_16sc(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_16scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_16scNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short integer Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_32u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_32u(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_32uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_32uNative(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit signed short integer Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_32s(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_32sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_32sNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short complex integer Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_32sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_32sc(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_32scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_32scNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit signed short integer Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_64s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_64s(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_64sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_64sNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit unsigned short complex integer Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_64sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_64sc(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_64scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_64scNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit floating point Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_32fNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit floating point complex Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_32fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_32fcNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit floating point Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_64fNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit floating point complex Average method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageErrorGetBufferSize_64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageError_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageError_64fcNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageError_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_8u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_8u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_8uNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_8uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_8s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_8s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_8sNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_8sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_16u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_16u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_16uNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_16uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_16sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_16sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_16scNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_16scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_32u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_32u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_32uNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_32uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_32sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_32sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_32scNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_32scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_64s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_64s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_64sNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_64sNative(
        int nLength,
        int[] hpBufferSize);


    public static int nppsAverageErrorGetBufferSize_64sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_64scNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_64scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_32fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_32fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageError_64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageErrorGetBufferSize_64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageErrorGetBufferSize_64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageErrorGetBufferSize_64fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * 8-bit unsigned char MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_8u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_8u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_8uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_8uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 8-bit signed char MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_8s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_8s(
        TypedPointer<Npp8s> pSrc1,
        TypedPointer<Npp8s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_8sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_8sNative(
        TypedPointer<Npp8s> pSrc1,
        TypedPointer<Npp8s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short integer MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_16u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_16u(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_16uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_16uNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit signed short integer MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_16s(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_16sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_16sNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short complex integer MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_16sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_16sc(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_16scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_16scNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short integer MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_32u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_32u(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_32uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_32uNative(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit signed short integer MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_32s(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_32sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_32sNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short complex integer MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_32sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_32sc(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_32scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_32scNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit signed short integer MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_64s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_64s(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_64sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_64sNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit unsigned short complex integer MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_64sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_64sc(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_64scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_64scNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit floating point MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_32fNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    public static int nppsMaximumRelativeError_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_32fcNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit floating point MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_64fNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit floating point complex MaximumRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsMaximumRelativeErrorGetBufferSize_64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsMaximumRelativeError_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsMaximumRelativeError_64fcNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsMaximumRelativeError_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_8u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_8u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_8uNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_8uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_8s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_8s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_8sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_8sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_16u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_16u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_16uNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_16uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_16sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_16sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_16scNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_16scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_32u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_32u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_32uNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_32uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_32sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_32sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_32scNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_32scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_64s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_64s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_64sNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_64sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_64sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_64sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_64scNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_64scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_32fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_32fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsMaximumRelativeError_64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsMaximumRelativeErrorGetBufferSize_64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsMaximumRelativeErrorGetBufferSize_64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsMaximumRelativeErrorGetBufferSize_64fcNative(
        int nLength,
        int[] hpBufferSize);


    /** @} */
    /**
     * <pre>
     * @defgroup signal_average_relative_error AverageRelativeError
     * Primitives for computing the AverageRelative error between two signals.
     * Given two signals \f$pSrc1\f$ and \f$pSrc2\f$ both with length \f$N\f$,
     * the average relative error is defined as
     * \f[AverageRelativeError = \frac{1}{N}\sum_{n=0}^{N-1}\frac{\left|pSrc1(n) - pSrc2(n)\right|}{max(\left|pSrc1(n)\right|, \left|pSrc2(n)\right|)}\f]
     *
     * If the signal is in complex format, the absolute value of the complex number is used.
     * @{
     *
     * </pre>
     */
    /**
     * <pre>
     * 8-bit unsigned char AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_8u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_8u(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_8uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_8uNative(
        TypedPointer<Npp8u> pSrc1,
        TypedPointer<Npp8u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 8-bit signed char AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_8s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_8s(
        TypedPointer<Npp8s> pSrc1,
        TypedPointer<Npp8s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_8sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_8sNative(
        TypedPointer<Npp8s> pSrc1,
        TypedPointer<Npp8s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short integer AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_16u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_16u(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_16uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_16uNative(
        TypedPointer<Npp16u> pSrc1,
        TypedPointer<Npp16u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit signed short integer AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_16s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_16s(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_16sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_16sNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 16-bit unsigned short complex integer AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_16sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_16sc(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_16scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_16scNative(
        TypedPointer<Npp16s> pSrc1,
        TypedPointer<Npp16s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short integer AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_32u to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_32u(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_32uNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_32uNative(
        TypedPointer<Npp32u> pSrc1,
        TypedPointer<Npp32u> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit signed short integer AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_32s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_32s(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_32sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_32sNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit unsigned short complex integer AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_32sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_32sc(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_32scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_32scNative(
        TypedPointer<Npp32s> pSrc1,
        TypedPointer<Npp32s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit signed short integer AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_64s to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_64s(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_64sNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_64sNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit unsigned short complex integer AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_64sc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_64sc(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_64scNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_64scNative(
        TypedPointer<Npp64s> pSrc1,
        TypedPointer<Npp64s> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit floating point AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_32f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_32f(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_32fNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_32fNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 32-bit floating point complex AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_32fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_32fc(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_32fcNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_32fcNative(
        TypedPointer<Npp32f> pSrc1,
        TypedPointer<Npp32f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit floating point AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_64f to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_64f(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_64fNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_64fNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * 64-bit floating point complex AverageRelative method.
     * @param pSrc1 \ref source_signal_pointer.
     * @param pSrc2 \ref source_signal_pointer.
     * @param nLength \ref length_specification.
     * @param pDst Pointer to the error result.
     * @param pDeviceBuffer Pointer to the required device memory allocation, \ref general_scratch_buffer.
     *        Use \ref nppsAverageRelativeErrorGetBufferSize_64fc to determine the minium number of bytes required.
     * @return
     *  \ref signal_data_error_codes, \ref length_error_codes.
     * </pre>
     */
    public static int nppsAverageRelativeError_64fc(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsAverageRelativeError_64fcNative(pSrc1, pSrc2, nLength, pDst, pDeviceBuffer));
    }
    private static native int nppsAverageRelativeError_64fcNative(
        TypedPointer<Npp64f> pSrc1,
        TypedPointer<Npp64f> pSrc2,
        int nLength,
        TypedPointer<Npp64f> pDst,
        TypedPointer<Npp8u> pDeviceBuffer);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_8u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_8u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_8uNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_8uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_8s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_8s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_8sNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_8sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_16u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_16u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_16uNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_16uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_16s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_16s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_16sNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_16sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_16sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_16sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_16scNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_16scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_32u.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_32u(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_32uNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_32uNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_32s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_32sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_32sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_32scNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_32scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_64s.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_64s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_64sNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_64sNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_64sc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_64sc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_64scNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_64scNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_32f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_32f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_32fNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_32fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_32fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_32fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_32fcNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_32fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_64f.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_64f(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_64fNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_64fNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * Device-buffer size (in bytes) for nppsAverageRelativeError_64fc.
     * @param nLength \ref length_specification.
     * @param hpBufferSize Required buffer size.  Important:
     *        hpBufferSize is a <em>host pointer.</em>
     * @return
     *  NPP_SUCCESS
     * </pre>
     */
    public static int nppsAverageRelativeErrorGetBufferSize_64fc(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsAverageRelativeErrorGetBufferSize_64fcNative(nLength, hpBufferSize));
    }
    private static native int nppsAverageRelativeErrorGetBufferSize_64fcNative(
        int nLength,
        int[] hpBufferSize);


    /**
     * <pre>
     * @defgroup signal_integral Integral
     * Compute the indefinite interal of a given signal.
     * The i-th element is computed to be
     * \f[
     *      s'_i = \sum_0^i s_j
     * \f]
     *
     * @{
     * </pre>
     */
    public static int nppsIntegralGetBufferSize_32s(
        int nLength,
        int[] hpBufferSize)
    {
        return JNpp.checkResult(nppsIntegralGetBufferSize_32sNative(nLength, hpBufferSize));
    }
    private static native int nppsIntegralGetBufferSize_32sNative(
        int nLength,
        int[] hpBufferSize);


    public static int nppsIntegral_32s(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        TypedPointer<Npp8u> pDeviceBuffer)
    {
        return JNpp.checkResult(nppsIntegral_32sNative(pSrc, pDst, nLength, pDeviceBuffer));
    }
    private static native int nppsIntegral_32sNative(
        TypedPointer<Npp32s> pSrc,
        TypedPointer<Npp32s> pDst,
        int nLength,
        TypedPointer<Npp8u> pDeviceBuffer);

}
